@@ -1,5 +1,4 @@
 /* ============================================================
- * File  : albumitemhandler.h
  * Author: Renchi Raju <renchi@pooh.tam.uiuc.edu>
  * Date  : 2003-09-26
  * Description : 
@@ -8,7 +7,7 @@
 
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
- * Public License as published bythe Free Software Foundation;
+ * Public License as published by the Free Software Foundation;
  * either version 2, or (at your option)
  * any later version.
  * 
@@ -22,7 +21,7 @@
 #ifndef ALBUMITEMHANDLER_H
 #define ALBUMITEMHANDLER_H
 
-#include <qstringlist.h>
+#include <kurl.h>
 
 /*! 
   AlbumItemHandler
@@ -38,12 +37,10 @@ public:
     AlbumItemHandler();
     virtual ~AlbumItemHandler();
     
-    virtual QStringList allItems() = 0;
-    virtual QStringList selectedItems() = 0;
-    virtual QStringList allItemsPath() = 0;
-    virtual QStringList selectedItemsPath() = 0;
+    virtual KURL::List allItems() = 0;
+    virtual KURL::List selectedItems() = 0;
     virtual void refresh() = 0;
-    virtual void refreshItems(const QStringList& items) = 0;
+    virtual void refreshItems(const KURL::List& items) = 0;
 
 protected:
 
