@@ -29,6 +29,7 @@
 
 #include <kconfig.h>
 #include <klocale.h>
+#include <kapplication.h>
 
 // Local includes.
 
@@ -54,16 +55,15 @@ public:
     AlbumSettings::AlbumSortOrder albumSortOrder;
     AlbumSettings::ImageSortOrder  imageSortOrder;
 
-    bool recurseTags;
     bool showToolTips;
     bool showSplash;
     bool useTrash;
+    bool scanAtStart;
     
     bool iconShowName;
     bool iconShowSize;
     bool iconShowDate;
     bool iconShowComments;
-    bool iconShowFileComments;
     bool iconShowResolution;
     bool iconShowTags;
     bool saveExifComments;
@@ -84,7 +84,7 @@ AlbumSettings * AlbumSettings::instance()
 AlbumSettings::AlbumSettings()
 {
     d = new AlbumSettingsPrivate;
-    d->config = new KConfig("digikamrc");
+    d->config = kapp->config();
 
     instance_ = this;
     
@@ -93,7 +93,6 @@ AlbumSettings::AlbumSettings()
 
 AlbumSettings::~AlbumSettings()
 {
-    delete d->config;
     delete d;
     instance_ = 0;
 }
@@ -111,29 +110,27 @@ void AlbumSettings::init()
     d->albumCollectionNames.append(i18n("Miscellaneous"));
     d->albumCollectionNames.sort();
 
-    d->albumSortOrder = AlbumSettings::ByFolder;
+    d->albumSortOrder  = AlbumSettings::ByFolder;
     d->imageSortOrder  = AlbumSettings::ByIName;
                                           
     d->imageFilefilter = "*.png *.jpg *.jpeg *.tif *.tiff *.gif *.bmp *.xpm *.ppm *.pnm *.xcf *.pcx";
-    d->movieFilefilter = "*.mpeg *.mpg *.avi *.mov";
+    d->movieFilefilter = "*.mpeg *.mpg *.avi *.mov *.wmf *.asf";
     d->audioFilefilter = "*.ogg *.mp3 *.wma *.wav";
-    d->rawFilefilter =   "*.crw *.nef *.raf *.mrw *.orf";
-    d->thumbnailSize = ThumbnailSize::Medium;
+    d->rawFilefilter   = "*.crw *.cr2 *.nef *.raf *.mrw *.orf *.pef *.x3f *.dcr *.kdc *.srf *.raw *.dng";
+    d->thumbnailSize   = ThumbnailSize::Medium;
 
-    d->recurseTags  = false;
     d->showToolTips = true;
     d->showSplash   = true;
     d->useTrash     = true;
     
-    d->iconShowName = false;
-    d->iconShowSize = false;
-    d->iconShowDate = true;
-    d->iconShowComments = true;
-    d->iconShowFileComments = false;
+    d->iconShowName       = false;
+    d->iconShowSize       = false;
+    d->iconShowDate       = true;
+    d->iconShowComments   = true;
     d->iconShowResolution = false;
-    d->iconShowTags = true;
-    d->saveExifComments = false;
-    d->exifRotate = false;
+    d->iconShowTags       = true;
+    d->saveExifComments   = false;
+    d->exifRotate         = false;
     d->exifSetOrientation = false;
 }
 
@@ -178,8 +175,6 @@ void AlbumSettings::readSettings()
     d->thumbnailSize = config->readNumEntry("Default Icon Size",
                              ThumbnailSize::Medium);
 
-    d->recurseTags   = config->readBoolEntry("Recurse Tags", false);
-
     d->showToolTips   = config->readBoolEntry("Show ToolTips", true);
     
     d->iconShowName = config->readBoolEntry("Icon Show Name", false); 
@@ -196,9 +191,6 @@ void AlbumSettings::readSettings()
     d->iconShowComments = config->readBoolEntry("Icon Show Comments",
                                                 true);
 
-    d->iconShowFileComments = config->readBoolEntry("Icon Show File Comments",
-                                                    false);
-
     d->iconShowTags = config->readBoolEntry("Icon Show Tags", true);
 
     d->currentTheme = config->readEntry("Theme", i18n("Default"));
@@ -221,6 +213,10 @@ void AlbumSettings::readSettings()
 
     d->useTrash =
         config->readBoolEntry("Use Trash", true);
+
+    d->scanAtStart =
+        config->readBoolEntry("Scan At Start", true);
+
 }
 
 void AlbumSettings::saveSettings()
@@ -255,8 +251,6 @@ void AlbumSettings::saveSettings()
     config->writeEntry("Default Icon Size",
                        QString::number(d->thumbnailSize));
 
-    config->writeEntry("Recurse Tags", d->recurseTags);
-
     config->writeEntry("Show ToolTips", d->showToolTips);
     
     config->writeEntry("Icon Show Name",
@@ -274,9 +268,6 @@ void AlbumSettings::saveSettings()
     config->writeEntry("Icon Show Comments",
                        d->iconShowComments);
                        
-    config->writeEntry("Icon Show File Comments",
-                       d->iconShowFileComments);
-                       
     config->writeEntry("Icon Show Tags",
                        d->iconShowTags);
 
@@ -298,6 +289,8 @@ void AlbumSettings::saveSettings()
     config->writeEntry("Show Splash", d->showSplash);
 
     config->writeEntry("Use Trash", d->useTrash);
+
+    config->writeEntry("Scan At Start", d->scanAtStart);
     
     config->sync();
 }
@@ -322,6 +315,16 @@ bool AlbumSettings::getShowSplashScreen() const
     return d->showSplash;
 }
 
+void AlbumSettings::setScanAtStart(bool val)
+{
+    d->scanAtStart = val;
+}
+
+bool AlbumSettings::getScanAtStart() const
+{
+    return d->scanAtStart;
+}
+
 void AlbumSettings::setAlbumCollectionNames(const QStringList& list)
 {
     d->albumCollectionNames = list;    
@@ -357,7 +360,7 @@ AlbumSettings::AlbumSortOrder AlbumSettings::getAlbumSortOrder() const
     return d->albumSortOrder;
 }
 
-void AlbumSettings::setImageSortOder(const ImageSortOrder order)
+void AlbumSettings::setImageSortOrder(const ImageSortOrder order)
 {
     d->imageSortOrder = order;    
 }
@@ -407,6 +410,26 @@ QString AlbumSettings::getRawFileFilter() const
     return d->rawFilefilter;
 }
 
+bool AlbumSettings::addImageFileExtension(const QString& newExt)
+{
+    if ( QStringList::split(" ", d->imageFilefilter).contains(newExt) ||
+         QStringList::split(" ", d->movieFilefilter).contains(newExt) ||
+         QStringList::split(" ", d->audioFilefilter).contains(newExt) ||
+         QStringList::split(" ", d->rawFilefilter  ).contains(newExt) )
+         return false; 
+
+    d->imageFilefilter = d->imageFilefilter + " " + newExt;
+    return true;
+}
+
+QString AlbumSettings::getAllFileFilter() const
+{
+    return d->imageFilefilter + " "
+        +  d->movieFilefilter + " "
+        +  d->audioFilefilter + " "
+        +  d->rawFilefilter;
+}
+
 void AlbumSettings::setDefaultIconSize(int val)
 {
     d->thumbnailSize = val;
@@ -447,16 +470,6 @@ bool AlbumSettings::getIconShowComments() const
     return d->iconShowComments;
 }
 
-void AlbumSettings::setIconShowFileComments(bool val)
-{
-    d->iconShowFileComments = val;
-}
-
-bool AlbumSettings::getIconShowFileComments() const
-{
-    return d->iconShowFileComments;
-}
-
 void AlbumSettings::setIconShowResolution(bool val)
 {
     d->iconShowResolution = val;
@@ -517,16 +530,6 @@ bool AlbumSettings::getExifSetOrientation() const
     return d->exifSetOrientation;
 }
 
-void AlbumSettings::setRecurseTags(bool val)
-{
-    d->recurseTags = val;
-}
-
-bool AlbumSettings::getRecurseTags() const
-{
-    return d->recurseTags;
-}
-
 void AlbumSettings::setShowToolTips(bool val)
 {
     d->showToolTips = val;
