@@ -58,6 +58,7 @@
 // Local includes.
 
 #include "albummanager.h"
+#include "albumlister.h"
 #include "album.h"
 #include "themeengine.h"
 #include "cameralist.h"
@@ -73,7 +74,6 @@
 #include "digikamapp.h"
 #include "splashscreen.h"
 #include "thumbnailsize.h"
-#include "digikamapp.h"
 
 DigikamApp::DigikamApp(bool detectCamera)
           : KMainWindow( 0, "Digikam" )
@@ -94,7 +94,8 @@ DigikamApp::DigikamApp(bool detectCamera)
     mAlbumSettings = new AlbumSettings();
     mAlbumSettings->readSettings();
 
-    mAlbumManager = new AlbumManager();
+    mAlbumManager = AlbumManager::instance();
+    AlbumLister::instance();
 
     mCameraList = new CameraList(this, locateLocal("appdata", "cameras.xml"));
 
@@ -111,11 +112,7 @@ DigikamApp::DigikamApp(bool detectCamera)
     applyMainWindowSettings(m_config);
 
     mAlbumManager->setLibraryPath(mAlbumSettings->getAlbumLibraryPath());
-
-    // Load Cameras
-    if(mSplash)
-        mSplash->message(i18n("Loading cameras"), AlignLeft, white);
-    loadCameras();
+    mAlbumManager->startScan();
 
     // Load KIPI Plugins.
     loadPlugins();
@@ -138,7 +135,7 @@ DigikamApp::~DigikamApp()
 {
     if (ImageWindow::imagewindow())
         delete ImageWindow::imagewindow();
-    
+
     if (mView)
         delete mView;
 
@@ -146,6 +143,7 @@ DigikamApp::~DigikamApp()
     delete mAlbumSettings;
 
     delete mAlbumManager;
+    delete AlbumLister::instance();
 
     m_instance = 0;
 }
@@ -423,17 +421,26 @@ void DigikamApp::setupActions()
     mImageExifOrientationActionMenu = new KActionMenu(i18n("Correct Exif Orientation Tag"),
                                                       actionCollection(),
                                                       "image_set_exif_orientation");
+    mImageExifOrientationActionMenu->setDelayed(false);
 
-    mImageSetExifOrientation1Action = new KAction(i18n("Normal"),0,actionCollection());
-    mImageSetExifOrientation2Action = new KAction(i18n("Flipped Horizontally"),0,actionCollection());
-    mImageSetExifOrientation3Action = new KAction(i18n("Rotated 180 Degrees"),0,actionCollection());
-    mImageSetExifOrientation4Action = new KAction(i18n("Flipped Vertically"),0,actionCollection());
-    mImageSetExifOrientation5Action = new KAction(i18n("Rotated 90 Degrees / Horiz. Flipped"),
-                                                       0, actionCollection());
-    mImageSetExifOrientation6Action = new KAction(i18n("Rotated 90 Degrees"),0,actionCollection());
-    mImageSetExifOrientation7Action = new KAction(i18n("Rotated 90 Degrees / Vert. Flipped"),
-                                                       0, actionCollection());
-    mImageSetExifOrientation8Action = new KAction(i18n("Rotated 270 Degrees"),0,actionCollection());
+    mImageSetExifOrientation1Action =
+        new KAction(i18n("Normal"),0,mImageExifOrientationActionMenu);
+    mImageSetExifOrientation2Action =
+        new KAction(i18n("Flipped Horizontally"),0,mImageExifOrientationActionMenu);
+    mImageSetExifOrientation3Action =
+        new KAction(i18n("Rotated 180 Degrees"),0,mImageExifOrientationActionMenu);
+    mImageSetExifOrientation4Action =
+        new KAction(i18n("Flipped Vertically"),0,mImageExifOrientationActionMenu);
+    mImageSetExifOrientation5Action =
+        new KAction(i18n("Rotated 90 Degrees / Horiz. Flipped"),
+                    0, mImageExifOrientationActionMenu);
+    mImageSetExifOrientation6Action =
+        new KAction(i18n("Rotated 90 Degrees"),0,mImageExifOrientationActionMenu);
+    mImageSetExifOrientation7Action =
+        new KAction(i18n("Rotated 90 Degrees / Vert. Flipped"),
+                    0, mImageExifOrientationActionMenu);
+    mImageSetExifOrientation8Action =
+        new KAction(i18n("Rotated 270 Degrees"),0,mImageExifOrientationActionMenu);
 
     mImageExifOrientationActionMenu->insert(mImageSetExifOrientation1Action);
     mImageExifOrientationActionMenu->insert(mImageSetExifOrientation2Action);
@@ -549,9 +556,28 @@ void DigikamApp::setupActions()
                                    actionCollection(),
                                    "gamma_adjustment");
 
+    // -----------------------------------------------------------
+
+    KAction* findAction = KStdAction::find(mView, SLOT(slotNewQuickSearch()),
+                                           actionCollection(), "search_quick");
+    findAction->setText(i18n("Quick Search..."));
+
+    findAction = KStdAction::find(mView, SLOT(slotNewAdvancedSearch()),
+                                  actionCollection(), "search_advanced");
+    findAction->setText(i18n("Advanced Search..."));
+    findAction->setShortcut("Ctrl+Alt+F");
+
+    // -----------------------------------------------------------
+
     // Provides a menu entry that allows showing/hiding the toolbar(s)
     setStandardToolBarMenuEnabled(true);
 
+    // Load Cameras -- do this before the createGUI so that the cameras
+    // are plugged into the toolbar at startup
+    if (mSplash)
+        mSplash->message(i18n("Loading cameras"), AlignLeft, white);
+    loadCameras();
+
     createGUI(QString::fromLatin1( "digikamui.rc" ), false);
 
     // Initialize Actions ---------------------------------------
@@ -571,6 +597,23 @@ void DigikamApp::setupActions()
 
     mAlbumSortAction->setCurrentItem((int)mAlbumSettings->getAlbumSortOrder());
     mImageSortAction->setCurrentItem((int)mAlbumSettings->getImageSortOrder());
+
+    int size = mAlbumSettings->getDefaultIconSize();
+    if (size == ThumbnailSize::Huge)
+    {
+        enableThumbSizePlusAction(false);
+        enableThumbSizeMinusAction(true);
+    }
+    else if (size == ThumbnailSize::Small)
+    {
+        enableThumbSizePlusAction(true);
+        enableThumbSizeMinusAction(false);
+    }
+    else
+    {
+        enableThumbSizePlusAction(true);
+        enableThumbSizeMinusAction(true);
+    }
 }
 
 void DigikamApp::enableThumbSizePlusAction(bool val)
@@ -628,34 +671,144 @@ void DigikamApp::slotAboutToShowForwardMenu()
 void DigikamApp::slot_albumSelected(bool val)
 {
     Album *album = mAlbumManager->currentAlbum();
-    if(album && !album->isRoot())
-    {
-        mDeleteAction->setEnabled(val);
-        mAddImagesAction->setEnabled(val);
-        mPropsEditAction->setEnabled(val);
-        mOpenInKonquiAction->setEnabled(val);
-    }
-    else
+    
+    if(album && !val)
     {
+        // No PAlbum is selected
         mDeleteAction->setEnabled(false);
         mAddImagesAction->setEnabled(false);
         mPropsEditAction->setEnabled(false);
         mOpenInKonquiAction->setEnabled(false);
+        mNewAction->setEnabled(false);
+        mAlbumImportAction->setEnabled(false);
+
+    }
+    else if(!album && !val)
+    {
+        // Groupitem selected (Collection/date)
+        mDeleteAction->setEnabled(false);
+        mAddImagesAction->setEnabled(false);
+        mPropsEditAction->setEnabled(false);
+        mOpenInKonquiAction->setEnabled(false);
+        mNewAction->setEnabled(false);
+        mAlbumImportAction->setEnabled(false);
+        
+        KAction *action;
+        for (action = m_kipiFileActionsImport.first(); action;
+             action = m_kipiFileActionsImport.next())
+        {
+            action->setEnabled(false);
+        }
+
+        for (action = m_kipiFileActionsExport.first(); action;
+             action = m_kipiFileActionsExport.next())
+        {
+            action->setEnabled(false);
+        }
+    }
+    else if(album && !album->isRoot() && album->type() == Album::PHYSICAL)
+    {
+        // Normal Album selected
+        mDeleteAction->setEnabled(true);
+        mAddImagesAction->setEnabled(true);
+        mPropsEditAction->setEnabled(true);
+        mOpenInKonquiAction->setEnabled(true);
+        mNewAction->setEnabled(true);
+        mAlbumImportAction->setEnabled(true);
+        
+        KAction *action;
+        for (action = m_kipiFileActionsImport.first(); action; 
+             action = m_kipiFileActionsImport.next())
+        {
+            action->setEnabled(true);
+        }
+
+        for (action = m_kipiFileActionsExport.first(); action; 
+             action = m_kipiFileActionsExport.next())
+        {
+            action->setEnabled(true);    
+        }        
+    }
+    else if(album && album->isRoot() && album->type() == Album::PHYSICAL)
+    {
+        // Root Album selected
+        mDeleteAction->setEnabled(false);
+        mAddImagesAction->setEnabled(false);
+        mPropsEditAction->setEnabled(false);
+       
+
+        if(album->type() == Album::PHYSICAL)
+        {
+            mNewAction->setEnabled(true);
+            mOpenInKonquiAction->setEnabled(true);
+            mAlbumImportAction->setEnabled(true);
+        }
+        else
+        {
+            mNewAction->setEnabled(false);
+            mOpenInKonquiAction->setEnabled(false);
+            mAlbumImportAction->setEnabled(false);            
+        }
+        
+        KAction *action;
+        for (action = m_kipiFileActionsImport.first(); action; 
+             action = m_kipiFileActionsImport.next())
+        {
+            action->setEnabled(false);
+        }
+
+        for (action = m_kipiFileActionsExport.first(); action; 
+             action = m_kipiFileActionsExport.next())
+        {
+            action->setEnabled(true);
+        }
     }
 }
 
 void DigikamApp::slot_tagSelected(bool val)
 {
     Album *album = mAlbumManager->currentAlbum();
-    if(album && !album->isRoot())
+    
+    if(!val)
     {
-        mDeleteTagAction->setEnabled(val);
-        mEditTagAction->setEnabled(val);
+        mDeleteTagAction->setEnabled(false);
+        mEditTagAction->setEnabled(false);
+    }
+    else if(!album->isRoot())
+    {
+        mDeleteTagAction->setEnabled(true);
+        mEditTagAction->setEnabled(true);
+        
+        KAction *action;
+        for (action = m_kipiFileActionsImport.first(); action;
+             action = m_kipiFileActionsImport.next())
+        {
+            action->setEnabled(false);
+        }
+
+        for (action = m_kipiFileActionsExport.first(); action;
+             action = m_kipiFileActionsExport.next())
+        {
+            action->setEnabled(true);
+        }
     }
     else
     {
         mDeleteTagAction->setEnabled(false);
         mEditTagAction->setEnabled(false);
+        
+        KAction *action;
+        for (action = m_kipiFileActionsImport.first(); action; 
+             action = m_kipiFileActionsImport.next())
+        {
+            action->setEnabled(false);
+        }
+
+        for (action = m_kipiFileActionsExport.first(); action; 
+             action = m_kipiFileActionsExport.next())
+        {
+            action->setEnabled(true);
+        }
     }
 }
 
@@ -708,7 +861,7 @@ void DigikamApp::slotCameraAdded(CameraType *ctype)
 {
     if (!ctype) return;
 
-    KAction *cAction = new KAction(ctype->title(), 0,
+    KAction *cAction = new KAction(ctype->title(), "camera", 0,
                                    this, SLOT(slotCameraConnect()),
                                    actionCollection(),
                                    ctype->title().utf8());
@@ -781,29 +934,16 @@ void DigikamApp::slotSetupCamera()
 
 void DigikamApp::slotSetupChanged()
 {
+    if(mAlbumSettings->getAlbumLibraryPath() != mAlbumManager->getLibraryPath())
+        mView->clearHistory();
     mAlbumManager->setLibraryPath(mAlbumSettings->getAlbumLibraryPath());
+    mAlbumManager->startScan();
+
     mView->applySettings(mAlbumSettings);
     updateDeleteTrashMenu();
     if (ImageWindow::imagewindow())
         ImageWindow::imagewindow()->applySettings();
 
-    int size = mAlbumSettings->getDefaultIconSize();
-    if (size == ThumbnailSize::Huge)
-    {
-        enableThumbSizePlusAction(false);
-        enableThumbSizeMinusAction(true);
-    }
-    else if (size == ThumbnailSize::Small)
-    {
-        enableThumbSizePlusAction(true);
-        enableThumbSizeMinusAction(false);
-    }
-    else
-    { 
-        enableThumbSizePlusAction(true);
-        enableThumbSizeMinusAction(true);
-    }
-
     m_config->sync();
 }
 
@@ -831,9 +971,9 @@ void DigikamApp::slotConfToolbars()
     saveMainWindowSettings(KGlobal::config());
     KEditToolbar *dlg = new KEditToolbar(actionCollection(), "digikamui.rc");
 
-    if (dlg->exec())
+    if(dlg->exec());
     {
-        createGUI("digikamui.rc");
+        createGUI(QString::fromLatin1( "digikamui.rc" ), false);
         applyMainWindowSettings(KGlobal::config());
         plugActionList( QString::fromLatin1("file_actions_import"), m_kipiFileActionsImport );
         plugActionList( QString::fromLatin1("image_actions"), m_kipiImageActions );
@@ -842,7 +982,6 @@ void DigikamApp::slotConfToolbars()
         plugActionList( QString::fromLatin1("album_actions"), m_kipiAlbumActions );
         plugActionList( QString::fromLatin1("file_actions_export"), m_kipiFileActionsExport );
     }
-
     delete dlg;
 }
 
@@ -898,6 +1037,11 @@ void DigikamApp::loadPlugins()
 
     KipiPluginLoader_->loadPlugins();
 
+    KipiInterface_->slotCurrentAlbumChanged(mAlbumManager->currentAlbum());
+
+    // Setting the initial menu options after all plugins have been loaded
+    mView->slot_albumSelected(mAlbumManager->currentAlbum());
+
     m_ImagePluginsLoader = new ImagePluginLoader(this, mSplash);
 }
 
