@@ -1,5 +1,4 @@
 /* ============================================================
- * File  : digikamfirstrun.h
  * Author: Renchi Raju <renchi@pooh.tam.uiuc.edu>
  *         Gilles Caulier <caulier dot gilles at free.fr>
  * Date  : 2003-02-01
@@ -9,7 +8,7 @@
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
- * Public License as published bythe Free Software Foundation;
+ * Public License as published by the Free Software Foundation;
  * either version 2, or (at your option)
  * any later version.
  * 
@@ -26,12 +25,12 @@
 // Qt includes.
 
 #include <kdialogbase.h>
-
+#include "digikam_export.h"
 class KConfig;
 class KURLRequester;
 class DigikamFirstFirstRunWidget;
 
-class DigikamFirstRun : public KDialogBase
+class DIGIKAM_EXPORT DigikamFirstRun : public KDialogBase
 {
     Q_OBJECT
 
