@@ -1,7 +1,5 @@
 //////////////////////////////////////////////////////////////////////////////
 //
-//    DIGIKAMVIEW.H
-//
 //    Copyright (C) 2002-2004 Renchi Raju <renchi at pooh.tam.uiuc.edu>
 //                            Gilles Caulier <caulier dot gilles at free.fr>
 //
@@ -25,13 +23,21 @@
 #define DIGIKAMVIEW_H
 
 // Qt includes.
-#include <qsplitter.h>
+#include <qhbox.h>
 #include <qstringlist.h>
 #include <qmap.h>
 
 // KDE includes.
 
-#include <kio/job.h>
+namespace KIO
+{
+class Job;
+}
+
+namespace Digikam
+{
+class Sidebar;
+};
 
 class QString;
 class QIconViewItem;
@@ -44,9 +50,14 @@ class AlbumIconItem;
 class AlbumSettings;
 class AlbumManager;
 class Album;
+class AlbumHistory;
+class DateFolderView;
+class TagFolderView;
+class TagFilterView;
+class SearchFolderView;
 
-class DigikamView : public QSplitter {
-
+class DigikamView : public QHBox
+{
     Q_OBJECT
 
 public:
@@ -56,17 +67,32 @@ public:
 
     void applySettings(const AlbumSettings* settings);
 
+    void clearHistory();
+    void getForwardHistory(QStringList &titles);
+    void getBackwardHistory(QStringList &titles);    
+    
 private:
 
     void setupConnections();
+    void loadViewState();
+    void saveViewState();
 
 private:
 
     DigikamApp               *mParent;
-    AlbumFolderView          *mFolderView;
+    AlbumFolderView          *mFolderView;    
     AlbumIconView            *mIconView;
     AlbumManager             *mAlbumMan;
-
+    AlbumHistory             *mAlbumHistory;
+    Digikam::Sidebar         *mMainSidebar;
+    DateFolderView           *mDateFolderView;
+    TagFolderView            *mTagFolderView;
+    SearchFolderView         *mSearchFolderView;
+    Digikam::Sidebar         *mRightSidebar;
+    TagFilterView            *mTagFilterView;
+    int                      mInitialAlbumID;
+    QSplitter                *mSplitter;
+    
 public slots:
 
     void slot_newAlbum();
@@ -80,16 +106,23 @@ public slots:
     void slot_albumAddImages();
     void slot_albumOpenInKonqui();
     void slotAlbumImportFolder();
+    void slotAlbumHistoryBack(int steps=1);
+    void slotAlbumHistoryForward(int steps=1);
+    void slotAlbumDeleted(Album *album);
+    void slotSelectAlbum(const KURL &url);
 
     // Tag action slots
     void slotNewTag();
     void slotDeleteTag();
     void slotEditTag();
+
+    // Search action slots
+    void slotNewQuickSearch();
+    void slotNewAdvancedSearch();
     
     // Image action slots
     void slot_imageView(AlbumIconItem* iconItem=0);
     void slot_imageCommentsEdit(AlbumIconItem* iconItem=0);
-    void slot_imageExifInfo(AlbumIconItem* iconItem=0);
     void slot_imageExifOrientation(int orientation);
     void slot_imageRename(AlbumIconItem* iconItem=0);
     void slot_imageDelete();
@@ -98,19 +131,21 @@ public slots:
     void slotSelectNone();
     void slotSelectInvert();
     void slotSortImages(int order);
-  
+
+    void slot_albumSelected(Album* album);
+    
 private slots:
 
+    void slotAllAlbumsLoaded();
+    
     void slot_imageSelected();
-    void slot_albumSelected(Album* album);
 
     void slot_albumsCleared();
     void slot_albumHighlight();
 
     void slot_imageCopyResult(KIO::Job* job);
 
-    void slotFolderViewInFocus();
-    void slotIconViewInFocus();
+    void slotLeftSidebarChangedTab(QWidget* w);
     
 signals:
 
