@@ -1,9 +1,10 @@
 /* ============================================================
  * Author: Renchi Raju <renchi@pooh.tam.uiuc.edu>
+ *         Joern Ahrens <joern.ahrens@kdemail.net>
  * Date  : 2004-06-26
  * Description : 
  * 
- * Copyright 2004 by Renchi Raju
+ * Copyright 2004, 2005 by Renchi Raju, Joern Ahrens
 
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -30,16 +31,31 @@
 
 class QWidget;
 
-class AlbumItemsDrag : public KURLDrag
+/**
+ * Provides a drag object for a list of KURLs with its related database IDs.
+ *
+ * Images can be moved through ItemDrag. It is possible to move them on
+ * another application which understands KURLDrag, like konqueror, to
+ * copy the images. Digikam can use the IDs, if ItemDrag is dropped
+ * on digikam itself.
+ * The kioURLs are internally used with the digikamalbums kioslave.
+ * The "normal" KURLDrag urls are used for external drops (k3b, gimp, ...)
+ */
+class ItemDrag : public KURLDrag
 {
 public:
 
-    AlbumItemsDrag(const KURL::List& urls, const QValueList<int>& dirIDs,
-                   QWidget* dragSource=0, const char* name=0);
+    ItemDrag(const KURL::List& urls, const KURL::List& kioURLs,
+             const QValueList<int>& albumIDs,
+             const QValueList<int>& albumIDs,
+             QWidget* dragSource=0, const char* name=0);
 
     static bool canDecode(const QMimeSource* e);
-    static bool decode(const QMimeSource* e, KURL::List &urls, 
-		       QValueList<int>& dirIDs);
+    static bool decode(const QMimeSource* e,
+                       KURL::List &urls,
+                       KURL::List &kioURLs,
+                       QValueList<int>& albumIDs,
+                       QValueList<int>& imageIDs);
 
 protected:
 
@@ -47,23 +63,12 @@ protected:
     virtual QByteArray encodedData(const char* mime) const;
 
 private:
-
-    QValueList<int> m_dirIDs;
+    
+    KURL::List      m_kioURLs;
+    QValueList<int> m_albumIDs;    
+    QValueList<int> m_imageIDs;
 };
 
-class TagItemsDrag : public AlbumItemsDrag
-{
-public:
-
-    TagItemsDrag(const KURL::List& urls, const QValueList<int>& dirIDs,
-                 QWidget* dragSource=0, const char* name=0);
-
-    static bool canDecode(const QMimeSource* e);
-
-protected:
-
-    virtual const char* format(int i) const;
-};
 
 /**
  * Provides a drag object for a tag
@@ -75,8 +80,6 @@ class TagDrag : public QDragObject
 {
 public:
 
-    /** Constructor. The source @param albumid is important.
-    */
     TagDrag(int albumid, QWidget *dragSource = 0, const char *name = 0);
     static bool     canDecode(const QMimeSource* e);
     
@@ -112,4 +115,28 @@ private:
     int     mAlbumID;
 };
 
+/**
+ * Provides a drag object for a list of tags
+ *
+ * When a tag is moved through drag'n'drop an object of this class 
+ * is created.
+ */
+class TagListDrag : public QDragObject
+{
+public:
+
+    TagListDrag(const QValueList<int>& tagIDs, QWidget *dragSource = 0,
+                const char *name = 0);
+    static bool canDecode(const QMimeSource* e);
+    
+protected:
+
+    QByteArray  encodedData( const char* ) const;
+    const char* format(int i) const;
+    
+private:
+
+    QValueList<int> m_tagIDs;
+};
+
 #endif /* DRAGOBJECTS_H */
