@@ -25,28 +25,29 @@
 
 #include <qguardedptr.h>
 #include <qpixmap.h>
+#include <qlistview.h>
 
 // KDE includes.
 
 #include <kdialogbase.h>
 
-// Local includes.
-
-#include "thumbnailjob.h"
-
 class QLabel;
-class QListView;
 class QPixmap;
 class QCheckListItem;
 class QCheckBox;
+class QPushButton;
+class QToolButton;
 
-class KFileMetaInfo;
 class KTextEdit;
+class KLineEdit;
+class KDateTimeEdit;
 
 class AlbumIconView;
 class AlbumIconItem;
-class AlbumLister;
 class TAlbum;
+class Album;
+class ThumbnailJob;
+class TAlbumListView;
 
 class ImageDescEdit : public KDialogBase
 {
@@ -66,24 +67,26 @@ protected:
 
 private:
 
-    AlbumIconView *m_view;
-    AlbumIconItem *m_currItem;
-    AlbumLister   *m_lister;
-    QLabel        *m_thumbLabel;
-    QLabel        *m_nameLabel;
-    KTextEdit     *m_commentsEdit;
-    QListView     *m_tagsView;
-    QCheckBox     *m_autoSaveBox;
-    bool           m_modified;
+    AlbumIconView   *m_view;
+    AlbumIconItem   *m_currItem;
+    QLabel          *m_thumbLabel;
+    QLabel          *m_nameLabel;
+    KTextEdit       *m_commentsEdit;
+    TAlbumListView  *m_tagsView;
+    QPushButton     *m_recentTagsBtn;
+    KLineEdit       *m_tagsSearchEdit;
+    QToolButton     *m_tagsSearchClearBtn;
+    KDateTimeEdit   *m_dateTimeEdit;
+    bool             m_modified;
 
-    void tagNew(TAlbum* parAlbum, QCheckListItem *item);
+    void tagNew(TAlbum* parAlbum);
     void tagEdit(TAlbum* album);
-    void tagDelete(TAlbum *album, QCheckListItem *item);
+    void tagDelete(TAlbum *album);
     
     QGuardedPtr<ThumbnailJob> m_thumbJob;
 
-    void populateTags();
-    void populateTags(QCheckListItem* parItem, TAlbum* parAlbum);
+    void     populateTags();
+    QPixmap  tagThumbnail(TAlbum* album) const;
     
 private slots:
 
@@ -93,11 +96,36 @@ private slots:
     void slotUser2();
     void slotApply();
     void slotOk();
-    void slotGotThumbnail(const KURL&, const QPixmap& pix,
-                          const KFileMetaInfo*);    
+    void slotGotThumbnail(const KURL&, const QPixmap& pix);
     void slotFailedThumbnail(const KURL&);
     void slotRightButtonClicked(QListViewItem *, const QPoint &, int);
+    void slotRecentTags();
+    void slotTagsSearchChanged();
 
+    void slotAlbumAdded(Album* a);
+    void slotAlbumDeleted(Album* a);
+    void slotAlbumIconChanged(Album* a);
+    void slotAlbumRenamed(Album* a);
+
+    void slotItemDeleted(AlbumIconItem* iconItem);
+    void slotCleared();
 };
- 
+
+// ------------------------------------------------------------------------
+
+class TAlbumListView : public QListView
+{
+    Q_OBJECT
+    
+public:
+
+    TAlbumListView(QWidget* parent);
+
+    void emitSignalItemStateChanged();
+    
+signals:
+
+    void signalItemStateChanged();
+};
+
 #endif  // IMAGEDESCEDIT_H
