@@ -39,6 +39,7 @@ extern "C"
 #include <qdatetime.h>
 #include <qfileinfo.h>
 #include <qfile.h>
+#include <qregexp.h>
 
 // KDE includes.
 
@@ -98,22 +99,24 @@ QString DigikamImageInfo::description()
     if (p)
     {
         AlbumDB* db = AlbumManager::instance()->albumDB();
-        return db->getItemCaption(p, _url.fileName());
+        return db->getItemCaption(p->id(), _url.fileName());
     }
 
     return QString::null;
 }
 
-void DigikamImageInfo::setTitle( const QString& name )
+void DigikamImageInfo::setTitle( const QString& newName )
 {
-    // TODO: what is this supposed to do exactly?
-
+    //  here we get informed that a plugin has renamed the file 
+    
     PAlbum* p = parentAlbum();
 
-    if ( p && !name.isEmpty() )
+    if ( p && !newName.isEmpty() )
     {
         AlbumDB* db = AlbumManager::instance()->albumDB();
-        db->moveItem(p, _url.fileName(), p, name);
+        db->moveItem(p->id(), _url.fileName(), p->id(), newName);
+        _url = _url.upURL();
+        _url.addPath(newName);
     }
 }
 
@@ -124,7 +127,7 @@ void DigikamImageInfo::setDescription( const QString& description )
     if ( p  )
     {
         AlbumDB* db = AlbumManager::instance()->albumDB();
-        db->setItemCaption(p, _url.fileName(), description);
+        db->setItemCaption(p->id(), _url.fileName(), description);
 
         AlbumSettings *settings = AlbumSettings::instance();
         if (settings->getSaveExifComments())
@@ -143,40 +146,35 @@ void DigikamImageInfo::setDescription( const QString& description )
     }
 }
 
+QDateTime DigikamImageInfo::time( KIPI::TimeSpec /*spec*/ )
+{
+    PAlbum* p = parentAlbum();
+
+    if (p)
+    {
+        AlbumDB* db = AlbumManager::instance()->albumDB();
+        return db->getItemDate(p->id(), _url.fileName());
+    }
+
+    return QDateTime();
+}
+
 void DigikamImageInfo::setTime(const QDateTime& time, KIPI::TimeSpec)
 {
-    // PENDING (Gilles) : This fonction must support KURL in the future !!!...
-    //                    Or the best way is a new AlbumDB method for to set the time of items.
-
     if ( !time.isValid() )
     {
         kdWarning() << k_funcinfo
-                    << "kipiinterface::DigikamImageInfo::setTime:Invalid datetime specified"
+                    << "Invalid datetime specified"
                     << endl;
+        return;
     }
 
-    QFileInfo fi(_url.path());
-    if ( !fi.exists() || !fi.isReadable() )
-    {
-        kdWarning() << k_funcinfo
-                    << "kipiinterface::DigikamImageInfo::setTime:Target does not exist "
-                       "or is unreadable"
-                    << endl;
-    }
+    PAlbum* p = parentAlbum();
 
-    struct utimbuf t;
-    t.actime  = time.toTime_t();
-    t.modtime = time.toTime_t();
-
-    if ( ::utime( QFile::encodeName(_url.path()), &t ) != 0 )
-    {
-        kdWarning() << k_funcinfo
-                    << "kipiinterface::DigikamImageInfo::setTime:Failed to change "
-                       "image file date and time"
-                    << endl;
-    }
-    else
+    if ( p )
     {
+        AlbumDB* db = AlbumManager::instance()->albumDB();
+        db->setItemDate(p->id(), _url.fileName(), time);
         AlbumManager::instance()->refreshItemHandler( _url );
     }
 }
@@ -267,10 +265,10 @@ QString DigikamImageCollection::name()
 {
     if ( album_->type() == Album::TAG )
     {
-        return i18n("Tag: %1").arg(album_->getTitle());
+        return i18n("Tag: %1").arg(album_->title());
     }
     else
-        return album_->getTitle();
+        return album_->title();
 }
 
 QString DigikamImageCollection::category()
@@ -278,12 +276,12 @@ QString DigikamImageCollection::category()
     if ( album_->type() == Album::PHYSICAL )
     {
         PAlbum *p = dynamic_cast<PAlbum*>(album_);
-        return p->getCollection();
+        return p->collection();
     }
     else if ( album_->type() == Album::TAG )
     {
         TAlbum *p = dynamic_cast<TAlbum*>(album_);
-        return i18n("Tag: %1").arg(p->getURL());
+        return i18n("Tag: %1").arg(p->url());
     }
     else
         return QString::null;
@@ -294,7 +292,7 @@ QDate DigikamImageCollection::date()
     if ( album_->type() == Album::PHYSICAL )
     {
         PAlbum *p = dynamic_cast<PAlbum*>(album_);
-        return p->getDate();
+        return p->date();
     }
     else
         return QDate();
@@ -305,21 +303,50 @@ QString DigikamImageCollection::comment()
     if ( album_->type() == Album::PHYSICAL )
     {
         PAlbum *p = dynamic_cast<PAlbum*>(album_);
-        return p->getCaption();
+        return p->caption();
     }
     else
         return QString::null;
 }
 
+static QValueList<QRegExp> makeFilterList( const QString &filter )
+{
+    QValueList<QRegExp> regExps;
+    if ( filter.isEmpty() )
+        return regExps;
+
+    QChar sep( ';' );
+    int i = filter.find( sep, 0 );
+    if ( i == -1 && filter.find( ' ', 0 ) != -1 )
+        sep = QChar( ' ' );
+
+    QStringList list = QStringList::split( sep, filter );
+    QStringList::Iterator it = list.begin();
+    while ( it != list.end() ) {
+        regExps << QRegExp( (*it).stripWhiteSpace(), false, true );
+        ++it;
+    }
+    return regExps;
+}
+
+static bool matchFilterList( const QValueList<QRegExp>& filters,
+                             const QString &fileName )
+{
+    QValueList<QRegExp>::ConstIterator rit = filters.begin();
+    while ( rit != filters.end() ) {
+        if ( (*rit).exactMatch(fileName) )
+            return true;
+        ++rit;
+    }
+    return false;
+}
+
 KURL::List DigikamImageCollection::images()
 {
     switch ( tp_ )
     {
     case AllItems:
     {
-        // PENDING (Gilles) : Support KURL !...
-        // Or a new method on PAlbum for to get all KURL items from an Album.
-
         if (album_->type() == Album::PHYSICAL)
         {
             return imagesFromPAlbum(dynamic_cast<PAlbum*>(album_));
@@ -362,77 +389,53 @@ KURL::List DigikamImageCollection::images()
 
 KURL::List DigikamImageCollection::imagesFromPAlbum(PAlbum* album) const
 {
-    // if this album is the current album, then its already open
-    // just return whatevers visible in the albumitemhandler
-    if ( album == AlbumManager::instance()->currentAlbum() )
-    {
-        AlbumItemHandler* handler =
-            AlbumManager::instance()->getItemHandler();
-        if (handler)
-        {
-            return handler->allItems();
-        }
-        else
-        {
-            return KURL::List();
-        }
-    }
-
-    // else load the directory and return the items found
-
-    // TODO: use a regexp to catch mix of upper-lower cases
-    QString filter = imgFilter_.lower() + " " + imgFilter_.upper();
-
-    QStringList items;
-    QDir dir(album->getKURL().path(), filter,
-             QDir::Name|QDir::IgnoreCase, QDir::Files|QDir::Readable);
-
-    QStringList Files = dir.entryList();
-
-    for ( QStringList::Iterator it = Files.begin() ; it != Files.end() ; ++it )
-        items.append(album->getKURL().path(1) + *it);
-
-    return KURL::List(items);
-}
-
-KURL::List DigikamImageCollection::imagesFromTAlbum(TAlbum* album) const
-{
-    // if this album is the current album, then its already open
-    // just return whatevers visible in the albumitemhandler
-    if ( album == AlbumManager::instance()->currentAlbum() )
-    {
-        AlbumItemHandler* handler =
-            AlbumManager::instance()->getItemHandler();
-        if (handler)
-            return handler->allItems();
-        else
-            return KURL::List();
-    }
-
-    // else get the images from the database and return the items found
+    // get the images from the database and return the items found
 
     AlbumDB* db = AlbumManager::instance()->albumDB();
 
     QStringList     urls;
-    QValueList<int> dirIDs;
 
     db->beginTransaction();
 
-    db->getItemsInTAlbum(album, urls, dirIDs);
+    urls = db->getItemURLsInAlbum(album->id());
 
     db->commitTransaction();
 
-    QString basePath(AlbumManager::instance()->getLibraryPath());
-    if (!basePath.endsWith("/"))
-        basePath += "/";
+    KURL::List urlList;
+
+    QValueList<QRegExp> regex = makeFilterList(imgFilter_);
+    
+    for (QStringList::iterator it = urls.begin(); it != urls.end(); ++it)
+    {
+        if (matchFilterList(regex, *it))
+            urlList.append(*it);
+    }
+
+    return urlList;
+}
+
+KURL::List DigikamImageCollection::imagesFromTAlbum(TAlbum* album) const
+{
+    // get the images from the database and return the items found
+
+    AlbumDB* db = AlbumManager::instance()->albumDB();
+
+    QStringList     urls;
+
+    db->beginTransaction();
+
+    urls = db->getItemURLsInTag(album->id());
+
+    db->commitTransaction();
 
     KURL::List urlList;
 
-    QStringList::iterator     itU = urls.begin();
-    while (itU != urls.end())
+    QValueList<QRegExp> regex = makeFilterList(imgFilter_);
+    
+    for (QStringList::iterator it = urls.begin(); it != urls.end(); ++it)
     {
-        urlList.append(KURL(basePath + *itU));
-        itU++;
+        if (matchFilterList(regex, *it))
+            urlList.append(*it);
     }
 
     return urlList;
@@ -444,7 +447,9 @@ KURL DigikamImageCollection::path()
     if (album_->type() == Album::PHYSICAL)
     {
         PAlbum *p = dynamic_cast<PAlbum*>(album_);
-        return p->getKURL();
+        KURL url;
+        url.setPath(p->folderPath());
+        return url;
     }
     else
     {
@@ -452,7 +457,7 @@ KURL DigikamImageCollection::path()
                     << "kipiinterface::DigikamImageCollection::path:Requesting kurl "
                        "from a virtual album"
                     << endl;
-        return KURL(album_->getURL());
+        return QString();
     }
 }
 
@@ -461,7 +466,9 @@ KURL DigikamImageCollection::uploadPath()
     if (album_->type() == Album::PHYSICAL)
     {
         PAlbum *p = dynamic_cast<PAlbum*>(album_);
-        return p->getKURL();
+        KURL url;
+        url.setPath(p->folderPath());
+        return url;
     }
     else
     {
@@ -469,7 +476,7 @@ KURL DigikamImageCollection::uploadPath()
                     << "kipiinterface::DigikamImageCollection::uploadPath:Requesting kurl "
                        "from a virtual album"
                     << endl;
-        return KURL(album_->getURL());
+        return KURL();
     }
 }
 
@@ -496,6 +503,13 @@ bool DigikamImageCollection::isDirectory()
     }
 }
 
+bool DigikamImageCollection::operator==(ImageCollectionShared& imgCollection)
+{
+    DigikamImageCollection* thatCollection =
+        static_cast<DigikamImageCollection*>(&imgCollection);
+
+    return (album_ == thatCollection->album_);
+}
 
 /////////////////////////////////////////////////////////////////////////////////////////////////////////
 ///////////////////////// KIPI INTERFACE IMPLEMENTATION CLASS //////////////////////////////////////////
@@ -553,8 +567,8 @@ QValueList<KIPI::ImageCollection> DigikamKipiInterface::allAlbums()
 
     QString fileFilter(fileExtensions());
 
-    PAlbumList palbumList = albumManager_->pAlbums();
-    for ( QValueList<PAlbum*>::Iterator it = palbumList.begin();
+    AlbumList palbumList = albumManager_->allPAlbums();
+    for ( AlbumList::Iterator it = palbumList.begin();
           it != palbumList.end(); ++it )
     {
         // don't add the root album
@@ -567,12 +581,8 @@ QValueList<KIPI::ImageCollection> DigikamKipiInterface::allAlbums()
         result.append( KIPI::ImageCollection( col ) );
     }
 
-    /*
-     * Disable this till the imagesgallery plugin is fixed
-     */
-
-    TAlbumList talbumList = albumManager_->tAlbums();
-    for ( QValueList<TAlbum*>::Iterator it = talbumList.begin();
+    AlbumList talbumList = albumManager_->allTAlbums();
+    for ( AlbumList::Iterator it = talbumList.begin();
           it != talbumList.end(); ++it )
     {
         // don't add the root album
@@ -585,7 +595,6 @@ QValueList<KIPI::ImageCollection> DigikamKipiInterface::allAlbums()
         result.append( KIPI::ImageCollection( col ) );
     }
 
-
     return result;
 }
 
@@ -626,8 +635,6 @@ bool DigikamKipiInterface::addImage( const KURL& url, QString& errmsg )
         return false;
     }
 
-    // Renchi: No need to have an 'AlbumDB::addItem()' method ?
-
     albumManager_->refreshItemHandler( url );
 
     return true;
@@ -650,7 +657,7 @@ void DigikamKipiInterface::delImage( const KURL& url )
     if ( palbum )
     {
         // delete the item from the database
-        albumDB_->deleteItem( palbum, url.fileName() );
+        albumDB_->deleteItem( palbum->id(), url.fileName() );
     }
     else
     {
