@@ -19,7 +19,6 @@
  * 
  * ============================================================ */
 
-
 #ifdef HAVE_CONFIG_H
 #include <config.h>
 #endif
@@ -29,6 +28,7 @@
 #include <qstring.h>
 #include <qstringlist.h>
 #include <qfileinfo.h>
+#include <qfile.h>
 
 // KDE includes
  
@@ -46,14 +46,11 @@
 
 #include <libkipi/version.h>
 
-extern "C"
-{
-#include <locale.h>
-}
-
 // Local includes.
 
 #include "version.h"
+#include "albumdb.h"
+#include "albummanager.h"
 #include "digikamapp.h"
 #include "digikamfirstrun.h"
 
@@ -65,15 +62,17 @@ static KCmdLineOptions options[] =
 
 int main(int argc, char *argv[])
 {
-    QString Description = i18n("A Photo-Management Application for KDE") + "\n" + 
-                          i18n("Using Kipi library version %1").arg(kipi_version);
+    QString description = QString(I18N_NOOP("A Photo-Management Application for KDE")) +
+                          QString("\n") + 
+                          QString(I18N_NOOP("Using Kipi library version %1"))
+                          .arg(kipi_version);
     
     KAboutData aboutData( "digikam", 
                           I18N_NOOP("digiKam"),
-                          digikam_version,        // Release number available in version.h to the top source dir.
-                          Description.latin1(),
+                          digikam_version,        
+                          description.latin1(),
                           KAboutData::License_GPL,
-                          I18N_NOOP("(c) 2002-2005, Digikam developers team"),
+                          I18N_NOOP("(c) 2002-2005, digiKam developers team"),
                           0,
                           "http://www.digikam.org");
 
@@ -92,6 +91,11 @@ int main(int argc, char *argv[])
                           "kde at jokele.de",
                           0);
 
+    aboutData.addAuthor ( "Tom Albers",
+                          I18N_NOOP("Developer"),
+                          "tomalbers at kde.nl",
+                          0);
+    
     aboutData.addAuthor ( "Ralf Holzer",
                           I18N_NOOP("Developer"),
                           "kde at ralfhoelzer.com",
@@ -187,13 +191,14 @@ int main(int argc, char *argv[])
                           "yves dot chaufour at wanadoo.fr",
                           0);
 
-    aboutData.addCredit ( "Tom Albers",
-                          I18N_NOOP("digiKam bugs.kde.org frontman, patches and feedback"),
-                          "tomalbers at kde.nl",
+    aboutData.addCredit ( "Tung Nguyen",
+                          I18N_NOOP("Bug reports and Feedback"),
+                          "ntung at free.fr",
                           0);
-    
+
+
     KCmdLineArgs::init( argc, argv, &aboutData );
-    KCmdLineArgs::addCmdLineOptions( options ); // Add our own options.
+    KCmdLineArgs::addCmdLineOptions( options ); 
 
     KApplication app;
 
@@ -226,35 +231,9 @@ int main(int argc, char *argv[])
         return app.exec();
     }
 
-    // Check the locale setting and see if it has changed
+    AlbumManager* man = new AlbumManager();
+    man->setLibraryPath(albumPath);
 
-    QString currLocale(setlocale(0,0));
-    
-    config->setGroup("General Settings");
-    if (!config->hasKey("Locale"))
-    {
-        config->writeEntry("Locale", currLocale);
-    }
-    else
-    {
-        QString savedLocale = config->readEntry("Locale");
-        if (savedLocale != currLocale)
-        {
-            int result = KMessageBox::warningYesNo(0,
-                                                   i18n("Your locale has changed from the previous time "
-                                                        "digiKam was run. This can cause unexpected "
-                                                        "problems. If you are sure that you want to "
-                                                        "continue, click on 'Yes' to start digiKam. "
-                                                        "Otherwise, click on 'No' and correct your "
-                                                        "locale setting before restarting digiKam"));
-            if (result != KMessageBox::Yes)
-                return 0;
-
-            config->writeEntry("Locale", currLocale);
-        }
-    }
-    
-    
     // Register image formats (especially for TIFF )
     KImageIO::registerFormats();
 
