@@ -23,8 +23,7 @@
 
 #include <qpopupmenu.h>
 #include <qvaluelist.h>
-
-class AlbumIconView;
+#include <qpixmap.h>
 
 class TagsPopupMenu : public QPopupMenu
 {
@@ -32,8 +31,14 @@ class TagsPopupMenu : public QPopupMenu
 
 public:
 
-    TagsPopupMenu(AlbumIconView* view, int addToID,
-                  bool onlyAssignedTags=false);
+    enum Mode
+    {
+        ASSIGN = 0,
+        REMOVE
+    };
+    
+    TagsPopupMenu(const QValueList<Q_LLONG>& selectedImageIDs,
+                  int addToID, Mode mode);
     ~TagsPopupMenu();
 
 private:
@@ -42,10 +47,11 @@ private:
     QPopupMenu* buildSubMenu(int tagid);
     bool        showThisTag(int tagid);
 
-    AlbumIconView*   m_view;
+    QValueList<Q_LLONG>  m_selectedImageIDs;
     int              m_addToID;
-    bool             m_onlyAssignedTags;
+    Mode             m_mode;
     QValueList<int>  m_assignedTags;
+    QPixmap          m_addTagPix;
         
 private slots:
 
