@@ -25,11 +25,14 @@
 
 #include <kdialogbase.h>
 
+class QTimer;
+
 class KIntNumInput;
 
 namespace Digikam
 {
-class ImagePreviewWidget;
+class ImagePannelWidget;
+class GaussianBlur;
 }
 
 class ImageEffect_Blur : public KDialogBase
@@ -43,16 +46,41 @@ public:
 
 private:
 
+    enum RunningMode
+    {
+    NoneRendering=0,
+    PreviewRendering,
+    FinalRendering
+    };
+    
+    int           m_currentRenderingMode;
+    
     QWidget      *m_parent;
     
+    QTimer       *m_timer;
+            
     KIntNumInput *m_radiusInput;
     
-    Digikam::ImagePreviewWidget *m_imagePreviewWidget;
+    Digikam::GaussianBlur      *m_threadedFilter;
+    
+    Digikam::ImagePannelWidget *m_imagePreviewWidget;
     
 private slots:
 
     void slotEffect();
     void slotOk();
+    void slotTimer();
+    void slotCancel();
+    void slotUser1();
+    void slotDefault();
+    void slotFocusChanged(void);    
+    
+protected:
+
+    void closeEvent(QCloseEvent *e);
+    void customEvent(QCustomEvent *event);
+    void abortPreview(void);
+    void keyPressEvent(QKeyEvent *e);
 };
 
 #endif /* IMAGEEFFECT_BLUR_H */
