@@ -23,6 +23,8 @@
 
 #define XMD_H
 
+#include <digikam_export.h>
+
 // Qt Includes.
 
 #include <qcstring.h>
@@ -32,6 +34,8 @@
 #include <qfile.h>
 #include <qdir.h>
 #include <qwmatrix.h>
+#include <qregexp.h>
+#include <qapplication.h>
 
 // KDE includes.
 
@@ -45,6 +49,10 @@
 #include <kstandarddirs.h>
 #include <kmdcodec.h>
 #include <ktempfile.h>
+#include <ktrader.h>
+#include <klibloader.h>
+#include <kmimetype.h>
+#include <kio/thumbcreator.h>
 
 // C Ansi includes.
 
@@ -59,6 +67,7 @@ extern "C"
 #include <sys/types.h>
 #include <sys/ipc.h>
 #include <sys/shm.h>
+#include <sys/time.h>
 #include <png.h>
 }
 
@@ -70,8 +79,6 @@ extern "C"
 #define X_DISPLAY_MISSING 1
 #include <Imlib2.h>
 
-#include "digikam_export.h"
-
 using namespace KIO;
 
 extern "C"
@@ -279,10 +286,13 @@ static QImage loadPNG(const QString& path)
     return qimage;
 }
 
-kio_digikamthumbnailProtocol::kio_digikamthumbnailProtocol(const QCString &pool_socket,
-                                                           const QCString &app_socket)
-    : SlaveBase("kio_digikamthumbnail", pool_socket, app_socket)
+kio_digikamthumbnailProtocol::kio_digikamthumbnailProtocol(int argc, char** argv) 
+    : SlaveBase("kio_digikamthumbnail", argv[2], argv[3])
 {
+    argc_ = argc;
+    argv_ = argv;
+    app_  = 0;
+    
     createThumbnailDirs();
 }
 
@@ -336,18 +346,22 @@ void kio_digikamthumbnailProtocol::get(const KURL& url )
         // Try JPEG loading...
         if ( !loadJPEG(img, url.path()) )
         {
-            // Try to load with imlib2 API...
+            // Try to load with imlib2
             if ( !loadImlib2(img, url.path()) )
             {
-                // Try to load with QT/KDELib API...
+                // Try to load with QT/KDELib
                 if (!img.load(url.path()))
                 {
-                    // Try to load with dcraw
-                    loadDCRAW( img, url.path() );
+                    // Try to load with KDE thumbcreators
+                    if (!loadKDEThumbCreator(img, url.path()))
+                    {
+                        // Try to load with dcraw
+                        loadDCRAW( img, url.path() );
+                    }
                 }
             }
         }
-
+        
         if (img.isNull())
         {
             error(KIO::ERR_INTERNAL, i18n("Cannot create thumbnail for %1")
@@ -382,6 +396,12 @@ void kio_digikamthumbnailProtocol::get(const KURL& url )
     if (exif)
         exifRotate(url.path(), img);
 
+    if (img.isNull())
+    {
+        error(KIO::ERR_INTERNAL, "Thumbnail is null");
+        return;
+    }
+
     QByteArray imgData;
     QDataStream stream( imgData, IO_WriteOnly );
 
@@ -466,7 +486,7 @@ bool kio_digikamthumbnailProtocol::loadJPEG(QImage& image, const QString& path)
 
     jpeg_create_decompress(&cinfo);
     jpeg_stdio_src(&cinfo, inputFile);
-    jpeg_read_header(&cinfo, TRUE);
+    jpeg_read_header(&cinfo, true);
 
     int imgSize = QMAX(cinfo.image_width, cinfo.image_height);
 
@@ -642,6 +662,78 @@ bool kio_digikamthumbnailProtocol::loadDCRAW(QImage& image, const QString& path)
     return true;
 }
 
+bool kio_digikamthumbnailProtocol::loadKDEThumbCreator(QImage& image,
+                                                       const QString& path)
+{
+    // this sucks royally. some of the thumbcreators need an instance of
+    // app running so that they can use pixmap. till they get their 
+    // code fixed, we will have to create a qapp instance.
+    if (!app_)
+        app_ = new QApplication(argc_, argv_);
+    
+    QString mimeType = KMimeType::findByURL(path)->name();
+    if (mimeType.isEmpty())
+    {
+        kdDebug() << "Mimetype not found" << endl;
+        return false;
+    }
+
+    QString mimeTypeAlt = mimeType.replace(QRegExp("/.*"), "/*");
+    
+    QString plugin;
+    
+    KTrader::OfferList plugins = KTrader::self()->query("ThumbCreator");
+    for (KTrader::OfferList::ConstIterator it = plugins.begin(); it != plugins.end(); ++it)
+    {
+        QStringList mimeTypes = (*it)->property("MimeTypes").toStringList();
+        for (QStringList::ConstIterator mt = mimeTypes.begin(); mt != mimeTypes.end(); ++mt)
+        {
+            if  ((*mt) == mimeType || (*mt) == mimeTypeAlt)
+            {
+                plugin=(*it)->library();
+                break;
+            }
+        }
+        
+        if (!plugin.isEmpty())
+            break;
+    }
+
+    if (plugin.isEmpty())
+    {
+        kdDebug() << "No relevant plugin found " << endl;
+        return false;
+    }
+
+    KLibrary *library = KLibLoader::self()->library(QFile::encodeName(plugin));
+    if (!library)
+    {
+        kdDebug() << "Plugin library not found " << plugin << endl;
+        return false;
+    }
+
+    ThumbCreator *creator = 0;
+    newCreator create = (newCreator)library->symbol("new_creator");
+    if (create)
+        creator = create();
+
+    if (!creator)
+    {
+        kdDebug() << "Cannot load ThumbCreator " << plugin << endl;
+        return false;
+    }
+
+    if (!creator->create(path, cachedSize_, cachedSize_, image))
+    {
+        kdDebug() << "Cannot create thumbnail for " << path << endl;
+        delete creator;
+        return false;
+    }  
+
+    delete creator;
+    return true;
+}
+
 void kio_digikamthumbnailProtocol::createThumbnailDirs()
 {
     QString path = QDir::homeDirPath() + "/.thumbnails/";
@@ -658,14 +750,12 @@ void kio_digikamthumbnailProtocol::createThumbnailDirs()
 
 extern "C"
 {
-    DIGIKAMIMAGEPLUGINS_EXPORT int kdemain(int argc, char **argv)
+    DIGIKAM_EXPORT int kdemain(int argc, char **argv)
     {
         KLocale::setMainCatalogue("digikam");
         KInstance instance( "kio_digikamthumbnail" );
         ( void ) KGlobal::locale();
 
-        kdDebug() << "*** Starting kio_digikamthumbnail " << endl;
-
         if (argc != 4) {
             kdDebug() << "Usage: kio_digikamthumbnail  protocol domain-socket1 domain-socket2"
                       << endl;
@@ -674,10 +764,9 @@ extern "C"
 
         KImageIO::registerFormats();
 
-        kio_digikamthumbnailProtocol slave(argv[2], argv[3]);
+        kio_digikamthumbnailProtocol slave(argc, argv);
         slave.dispatchLoop();
 
-        kdDebug() << "*** kio_digikamthumbnail Done" << endl;
         return 0;
     }
 }
