@@ -13,15 +13,9 @@
  * Original Normalize Image algorithm copyrighted 1997 by 
  * Adam D. Moss <adam@foxbox.org> from Gimp 2.0 implementation.
  *
- * Original Gaussian Blur algorithm copyrighted 2005 by 
- * Pieter Z. Voloshyn <pieter_voloshyn at ame.com.br>.
- *
  * Original channel mixer algorithm copyrighted 2002 by 
  * Martin Guldahl <mguldahl at xmission dot com> from Gimp 2.2 
  * 
- * Original sharpening filter from from gimp 2.2
- * copyright 1997-1998 Michael Sweet (mike@easysw.com)
- *
  * Original HSL algorithm from from gimp 2.2
  * Copyright (C) 1995 Spencer Kimball and Peter Mattis
  * 
@@ -38,9 +32,6 @@
  * 
  * ============================================================ */
 
-#define CLAMP0255(a)  QMIN(QMAX(a,0), 255) 
-#define CLAMP(x,l,u) ((x)<(l)?(l):((x)>(u)?(u):(x)))
- 
 // C++ includes.
 
 #include <cstring>
@@ -49,7 +40,6 @@
 // KDE includes.
 
 #include <kdebug.h>
-#include <kapplication.h>
 
 // Digikam includes.
  
@@ -59,6 +49,8 @@
 
 // Local includes.
 
+#include "gaussianblur.h"
+#include "sharpen.h"
 #include "imagefilters.h"
 
 namespace Digikam
@@ -78,10 +70,7 @@ void ImageFilters::equalizeImage(uint *data, int w, int h)
     struct double_packet  high, low, intensity;
     struct double_packet *map;
     struct short_packet  *equalize_map;
-    int                   x, y;
-    unsigned int         *q;
     register long         i;               
-    unsigned char         r, g, b, a;
     
     // Create an histogram of the current image.     
     Digikam::ImageHistogram *histogram = new Digikam::ImageHistogram(data, w, h);
@@ -111,27 +100,30 @@ void ImageFilters::equalizeImage(uint *data, int w, int h)
     memset(&high,      0, sizeof(struct double_packet));            
     memset(&low,       0, sizeof(struct double_packet));
     
-    for(i = 0 ; i <= 255 ; ++i)
+    for(i = 0 ; i <= 255 ; i++)
        {
        intensity.red   += histogram->getValue(Digikam::ImageHistogram::RedChannel, i);
        intensity.green += histogram->getValue(Digikam::ImageHistogram::GreenChannel, i);
        intensity.blue  += histogram->getValue(Digikam::ImageHistogram::BlueChannel, i);
        intensity.alpha += histogram->getValue(Digikam::ImageHistogram::AlphaChannel, i);
-       map[i] = intensity;
+       map[i]          = intensity;
        }
     
     low =  map[0];
     high = map[255];
     memset(equalize_map, 0, 256*sizeof(short_packet));
     
-    for(i = 0 ; i <= 255 ; ++i)
+    for(i = 0 ; i <= 255 ; i++)
        {
        if(high.red != low.red)
           equalize_map[i].red=(unsigned short)((65535*(map[i].red-low.red))/(high.red-low.red));
+       
        if(high.green != low.green)
           equalize_map[i].green=(unsigned short)((65535*(map[i].green-low.green))/(high.green-low.green));
+       
        if(high.blue != low.blue)
           equalize_map[i].blue=(unsigned short)((65535*(map[i].blue-low.blue))/(high.blue-low.blue));
+       
        if(high.alpha != low.alpha)
           equalize_map[i].alpha=(unsigned short)((65535*(map[i].alpha-low.alpha))/(high.alpha-low.alpha));
        }
@@ -140,33 +132,35 @@ void ImageFilters::equalizeImage(uint *data, int w, int h)
     delete [] map;
     
     // Stretch the histogram.
+
+    uchar     red, green, blue, alpha;
+    imageData imagedata;
     
-    for(y = 0 ; y < h ; ++y)
+    for(i = 0 ; i < w*h ; i++)
        {
-       q = data + (w * y);
+       imagedata.raw = data[i];
+       red           = imagedata.channel.red;
+       green         = imagedata.channel.green;
+       blue          = imagedata.channel.blue;
+       alpha         = imagedata.channel.alpha;
+
+       if(low.red != high.red)
+           red = (equalize_map[red].red)/257;
+                
+       if(low.green != high.green)
+           green = (equalize_map[green].green)/257;
             
-       for(x = 0 ; x < w ; ++x)
-          {
-          if(low.red != high.red)
-             r = (equalize_map[(unsigned char)(q[x] >> 16)].red)/257;
-          else
-             r = (unsigned char)(q[x] >> 16);      
-          if(low.green != high.green)
-             g = (equalize_map[(unsigned char)(q[x] >> 8)].green)/257;
-          else
-             g = (unsigned char)(q[x] >> 8);       
-          if(low.blue != high.blue)
-             b = (equalize_map[(unsigned char)(q[x])].blue)/257;
-          else
-             b = (unsigned char)(q[x]);            
-          if(low.alpha != high.alpha)
-             a = (equalize_map[(unsigned char)(q[x] >> 24)].alpha)/257;
-          else
-             a = (unsigned char)(q[x] >> 24);      
-          
-          q[x] = (unsigned int)(a << 24) + (unsigned int)(r << 16) + 
-                 (unsigned int)(g << 8)  + (unsigned int)(b);                
-          }
+       if(low.blue != high.blue)
+           blue = (equalize_map[blue].blue)/257;
+            
+       if(low.alpha != high.alpha)
+           alpha = (equalize_map[alpha].alpha)/257;
+                    
+       imagedata.channel.red   = red;
+       imagedata.channel.green = green;
+       imagedata.channel.blue  = blue;
+       imagedata.channel.alpha = alpha;
+       data[i] = imagedata.raw;
        }
     
     delete [] equalize_map;
@@ -188,11 +182,8 @@ void ImageFilters::stretchContrastImage(uint *data, int w, int h)
     struct double_packet  high, low, intensity;
     struct short_packet  *normalize_map;
     long long             number_pixels;
-    int                   x, y;
-    unsigned int         *q;
     register long         i;
     unsigned long         threshold_intensity;
-    unsigned char         r, g, b, a;
         
     // Create an histogram of the current image.     
     Digikam::ImageHistogram *histogram = new Digikam::ImageHistogram(data, w, h);
@@ -382,7 +373,7 @@ void ImageFilters::stretchContrastImage(uint *data, int w, int h)
     
     memset(normalize_map, 0, 256*sizeof(struct short_packet));
     
-    for(i = 0 ; i <= (long)255 ; ++i)
+    for(i = 0 ; i <= (long)255 ; i++)
        {
        if(i < (long) low.red)
           normalize_map[i].red = 0;
@@ -413,32 +404,34 @@ void ImageFilters::stretchContrastImage(uint *data, int w, int h)
           normalize_map[i].alpha = (unsigned short)((65535*(i-low.alpha))/(high.alpha-low.alpha));
        }
 
-    for(y = 0 ; y < h ; ++y)
+    uchar     red, green, blue, alpha;
+    imageData imagedata;
+    
+    for(i = 0 ; i < w*h ; i++)
        {
-       q = data + (w * y);
+       imagedata.raw = data[i];
+       red           = imagedata.channel.red;
+       green         = imagedata.channel.green;
+       blue          = imagedata.channel.blue;
+       alpha         = imagedata.channel.alpha;
+
+       if(low.red != high.red)
+           red = (normalize_map[red].red)/257;
+                
+       if(low.green != high.green)
+           green = (normalize_map[green].green)/257;
             
-       for(x = 0 ; x < w ; ++x)
-          {
-          if(low.red != high.red)
-             r = (normalize_map[(unsigned char)(q[x] >> 16)].red)/257;
-          else
-             r = (unsigned char)(q[x] >> 16);      
-          if(low.green != high.green)
-             g = (normalize_map[(unsigned char)(q[x] >> 8)].green)/257;
-          else
-             g = (unsigned char)(q[x] >> 8);       
-          if(low.blue != high.blue)
-             b = (normalize_map[(unsigned char)(q[x])].blue)/257;
-          else
-             b = (unsigned char)(q[x]);            
-          if(low.alpha != high.alpha)
-             a = (normalize_map[(unsigned char)(q[x] >> 24)].alpha)/257;
-          else
-             a = (unsigned char)(q[x] >> 24);      
-          
-          q[x] = (unsigned int)(a << 24) + (unsigned int)(r << 16) + 
-                 (unsigned int)(g << 8)  + (unsigned int)(b);                
-          }
+       if(low.blue != high.blue)
+           blue = (normalize_map[blue].blue)/257;
+            
+       if(low.alpha != high.alpha)
+           alpha = (normalize_map[alpha].alpha)/257;
+                    
+       imagedata.channel.red   = red;
+       imagedata.channel.green = green;
+       imagedata.channel.blue  = blue;
+       imagedata.channel.alpha = alpha;
+       data[i] = imagedata.raw;
        }
     
     delete [] normalize_map;
@@ -449,36 +442,44 @@ void ImageFilters::stretchContrastImage(uint *data, int w, int h)
 
 void ImageFilters::normalizeImage(uint *data, int w, int h)
 {
-    NormalizeParam param;
-    int    x, i, b;
-    uchar  range;
-    uchar *p;
+    NormalizeParam  param;
+    int             x, i;
+    uchar           range;
 
     // Find min. and max. values.
     
     param.min   = 255;
     param.max   = 0;
 
-    for (i = 0 ; i < h*w ; ++i)
-        {
-        p = (uchar *)(data + i);
-        
-        for (b = 0 ; b < 3 ; ++b)
-           {
-           if (p[b] < param.min)
-              param.min = p[b];
-           if (p[b] > param.max)
-              param.max = p[b];
-           }
-        }
+    uchar         red, green, blue;
+    imageData     imagedata;
     
+    for (i = 0; i < w*h; i++)
+        {
+        imagedata.raw = data[i];
+        red = imagedata.channel.red;
+        
+        if (red < param.min) param.min = red;
+        if (red > param.max) param.max = red;
+
+        green = imagedata.channel.green;
+        
+        if (green < param.min) param.min = green;
+        if (green > param.max) param.max = green;
+
+        blue = imagedata.channel.blue;
+    
+        if (blue < param.min) param.min = blue;
+        if (blue > param.max) param.max = blue;
+        }
+
     // Calculate LUT. 
 
     range = (uchar)(param.max - param.min);
 
     if (range != 0)
        {
-       for (x = (int)param.min ; x <= (int)param.max ; ++x)
+       for (x = (int)param.min ; x <= (int)param.max ; x++)
           param.lut[x] = (uchar)(255 * (x - param.min) / range);
        }
     else
@@ -486,14 +487,20 @@ void ImageFilters::normalizeImage(uint *data, int w, int h)
 
     // Apply LUT to image.
        
-    for (i = 0 ; i < h*w ; ++i)
+    for (i = 0; i < w*h; i++)
         {
-        p = (uchar *)(data + i);
+        imagedata.raw = data[i];
         
-        for (b = 0 ; b < 3 ; ++b)
-           p[b] = param.lut[p[b]];
-  
-        p[3] = p[3];
+        red = imagedata.channel.red;
+        imagedata.channel.red = param.lut[red];
+
+        green = imagedata.channel.green;
+        imagedata.channel.green = param.lut[green];
+        
+        blue = imagedata.channel.blue;
+        imagedata.channel.blue = param.lut[blue];
+        
+        data[i] = imagedata.raw;
         }
 }
 
@@ -547,75 +554,27 @@ void ImageFilters::invertImage(uint *data, int w, int h)
        return;
        }
        
-    // Create the new empty destination image data space.
-    uint* desData = new uint[w*h];
-
-    int LineWidth = w * 4;
-    if (LineWidth % 4) LineWidth += (4 - LineWidth % 4);
-      
-    uchar* bits    = (uchar*)data;
-    uchar* newBits = (uchar*)desData;
-
-    int i = 0;
+    int           i;
+    uchar         red, green, blue;
+    imageData     imagedata;
     
-    for (int y = 0 ; y < h ; ++y)
+    for (i = 0; i < w*h; i++)
         {
-        for (int x = 0 ; x < w ; ++x)
-            {
-            i = y * LineWidth + 4 * x;
-
-            newBits[i+3] = 255 - bits[i+3];
-            newBits[i+2] = 255 - bits[i+2];
-            newBits[i+1] = 255 - bits[i+1];
-            newBits[ i ] = 255 - bits[ i ];
-            }
+        imagedata.raw = data[i];
+        red           = imagedata.channel.red;
+        green         = imagedata.channel.green;
+        blue          = imagedata.channel.blue;
+    
+        imagedata.channel.red   = 255 - red;
+        imagedata.channel.green = 255 - green;
+        imagedata.channel.blue  = 255 - blue;
+        data[i] = imagedata.raw;
         }
-                        
-    memcpy (data, desData, w*h*4);
-    delete [] desData;
 }
 
 //////////////////////////////////////////////////////////////////////////////
-// Performs blur image with less pixels.
-
-void ImageFilters::smartBlurImage(uint *data, int Width, int Height)
-{
-    if (!data || !Width || !Height)
-       {
-       kdWarning() << ("ImageFilters::smartBlurImage: no image data available!")
-                   << endl;
-       return;
-       }
-       
-    int LineWidth = Width * 4;
-    if (LineWidth % 4) LineWidth += (4 - LineWidth % 4);
-    
-    uchar* Bits = (uchar*)data;
-        
-    register int i = 0, j = 0, k = 0;
-    
-    for (int h = 1; h < Height - 1; h++)
-        {
-        for (int w = 1; w < Width - 1; w++)
-            {
-            i = h * LineWidth + 4 * w;
-            j = (h + 1) * LineWidth + 4 * w;
-            k = (h - 1) * LineWidth + 4 * w;
-
-            Bits[i+2] = (Bits[i-2] + Bits[j-2] + Bits[k-2] +
-                         Bits[i+2] + Bits[j+2] + Bits[k+2] +
-                         Bits[i+6] + Bits[j+6] + Bits[k+6]) / 9;
-            Bits[i+1] = (Bits[i-3] + Bits[j-3] + Bits[k-3] +
-                         Bits[i+1] + Bits[j+1] + Bits[k+1] +
-                         Bits[i+5] + Bits[j+5] + Bits[k+5]) / 9;
-            Bits[ i ] = (Bits[i-4] + Bits[j-4] + Bits[k-4] +
-                         Bits[ i ] + Bits[ j ] + Bits[ k ] +
-                         Bits[i+4] + Bits[j+4] + Bits[k+4]) / 9;
-            }
-        }
-}
-
-/* Function to apply the GaussianBlur on an image
+/* Function to apply the GaussianBlur on an image. This method do not use a 
+ * dedicaced thread.
  *
  * data             => The image data in RGBA mode.  
  * Width            => Width of image.                          
@@ -634,145 +593,15 @@ void ImageFilters::gaussianBlurImage(uint *data, int Width, int Height, int Radi
        }
 
     if (Radius > 100) Radius = 100;
-    
-    // Gaussian kernel computation using the Radius parameter.
-      
-    int    nKSize, nCenter;
-    double x, sd, factor, lnsd, lnfactor;
-    register int i, j, n, h, w;
+    if (Radius <= 0) return;
 
-    nKSize = 2 * Radius + 1;
-    nCenter = nKSize / 2;
-    int *Kernel = new int[nKSize];
+    QImage orgImage(Width, Height, 32);
+    memcpy( orgImage.bits(), data, orgImage.numBytes() );
 
-    lnfactor = (4.2485 - 2.7081) / 10 * nKSize + 2.7081;
-    lnsd = (0.5878 + 0.5447) / 10 * nKSize - 0.5447;
-    factor = exp (lnfactor);
-    sd = exp (lnsd);
-
-    for (i = 0; i < nKSize; i++)
-        {
-        x = sqrt ((i - nCenter) * (i - nCenter));
-        Kernel[i] = (int)(factor * exp (-0.5 * pow ((x / sd), 2)) / (sd * sqrt (2.0 * M_PI)));
-        }
-    
-    // Now, we need to convolve the image descriptor.
-    // I've worked hard here, but I think this is a very smart       
-    // way to convolve an array, its very hard to explain how I reach    
-    // this, but the trick here its to store the sum used by the       
-    // previous pixel, so we sum with the other pixels that wasn't get.
-    
-    int nSumR, nSumG, nSumB, nCount;
-    int nKernelWidth = Radius * 2 + 1;
-    int nStride = GetStride(Width);
-    
-    int LineWidth = Width * 4;                     
-    if (LineWidth % 4) LineWidth += (4 - LineWidth % 4);
-    
-    int    BitCount = LineWidth * Height;
-    uchar* pInBits  = (uchar*)data;
-    uchar* pOutBits = new uchar[BitCount];
-    uchar* pBlur    = new uchar[BitCount];
-    
-    // We need to copy our bits to blur bits
-    
-    memcpy (pBlur, pInBits, BitCount);     
-
-    // We need to alloc a 2d array to help us to store the values
-    
-    int** arrMult = Alloc2DArray (nKernelWidth, 256);
-    
-    for (i = 0; i < nKernelWidth; i++)
-        for (j = 0; j < 256; j++)
-            arrMult[i][j] = j * Kernel[i];
-
-    // We need to initialize all the loop and iterator variables
-    
-    nSumR = nSumG = nSumB = nCount = i = j = 0;
-
-    // Now, we enter in the main loop
-    
-    for (h = 0; h < Height; h++, i += nStride)
-        {
-        for (w = 0; w < Width; w++, i += 4)
-            {
-            // first of all, we need to blur the horizontal lines
-                
-            for (n = -Radius; n <= Radius; n++)
-               {
-               // if is inside...
-               if (IsInside (Width, Height, w + n, h))
-                    {
-                    // we points to the pixel
-                    j = i + n * 4;
-                    
-                    // finally, we sum the pixels using a method similar to assigntables
-                    nSumR += arrMult[n + Radius][pInBits[j+2]];
-                    nSumG += arrMult[n + Radius][pInBits[j+1]];
-                    nSumB += arrMult[n + Radius][pInBits[ j ]];
-                    
-                    // we need to add to the counter, the kernel value
-                    nCount += Kernel[n + Radius];
-                    }
-                }
-                
-            if (nCount == 0) nCount = 1;                    
-                
-            // now, we return to blur bits the horizontal blur values
-            pBlur[i+2] = (uchar)CLAMP (nSumR / nCount, 0, 255);
-            pBlur[i+1] = (uchar)CLAMP (nSumG / nCount, 0, 255);
-            pBlur[ i ] = (uchar)CLAMP (nSumB / nCount, 0, 255);
-            // ok, now we reinitialize the variables
-            nSumR = nSumG = nSumB = nCount = 0;
-            }
-        }
-
-    // getting the blur bits, we initialize position variables
-    i = j = 0;
-
-    // We enter in the second main loop
-    for (w = 0; w < Width; w++, i = w * 4)
-        {
-        for (h = 0; h < Height; h++, i += LineWidth)
-            {
-            // first of all, we need to blur the vertical lines
-            for (n = -Radius; n <= Radius; n++)
-                {
-                // if is inside...
-                if (IsInside(Width, Height, w, h + n))
-                    {
-                    // we points to the pixel
-                    j = i + n * LineWidth;
-                      
-                    // finally, we sum the pixels using a method similar to assigntables
-                    nSumR += arrMult[n + Radius][pBlur[j+2]];
-                    nSumG += arrMult[n + Radius][pBlur[j+1]];
-                    nSumB += arrMult[n + Radius][pBlur[ j ]];
-                    
-                    // we need to add to the counter, the kernel value
-                    nCount += Kernel[n + Radius];
-                    }
-                }
-                
-            if (nCount == 0) nCount = 1;                    
-                
-            // now, we return to bits the vertical blur values
-            pOutBits[i+2] = (uchar)CLAMP (nSumR / nCount, 0, 255);
-            pOutBits[i+1] = (uchar)CLAMP (nSumG / nCount, 0, 255);
-            pOutBits[ i ] = (uchar)CLAMP (nSumB / nCount, 0, 255);
-                
-            // ok, now we reinitialize the variables
-            nSumR = nSumG = nSumB = nCount = 0;
-            }
-        }
-
-    memcpy (data, pOutBits, BitCount);   
-       
-    // now, we must free memory
-    Free2DArray (arrMult, nKernelWidth);
-    delete [] pBlur;
-    delete [] pOutBits;
-    delete [] Kernel;
+    Digikam::GaussianBlur *threadedFilter = new Digikam::GaussianBlur(&orgImage, 0L, Radius);
+    QImage imDest = threadedFilter->getTargetImage();
+    memcpy( data, imDest.bits(), imDest.numBytes() );
+    delete threadedFilter;
 }
 
 void ImageFilters::channelMixerImage(uint *data, int Width, int Height, bool bPreserveLum, bool bMonochrome,
@@ -788,7 +617,7 @@ void ImageFilters::channelMixerImage(uint *data, int Width, int Height, bool bPr
        return;
        }
         
-    register int h, w, i = 0;
+    register int i;
     uchar        nGray, red, green , blue;
     imageData    imagedata;
     
@@ -796,29 +625,26 @@ void ImageFilters::channelMixerImage(uint *data, int Width, int Height, bool bPr
     double gnorm = CalculateNorm (grGain, ggGain, gbGain, bPreserveLum);
     double bnorm = CalculateNorm (brGain, bgGain, bbGain, bPreserveLum);
         
-    for (h = 0; h < Height; h++)
+    for (i = 0; i < Width*Height; i++)
         {
-        for (w = 0; w < Width; w++, i++)
+        imagedata.raw = data[i];
+        red           = imagedata.channel.red;
+        green         = imagedata.channel.green;
+        blue          = imagedata.channel.blue;
+            
+        if (bMonochrome)
             {
-            imagedata.raw = data[i];
-            red           = imagedata.channel.red;
-            green         = imagedata.channel.green;
-            blue          = imagedata.channel.blue;
-            
-            if (bMonochrome)
-                {
-                nGray = MixPixel (rrGain, rgGain, rbGain, red, green, blue, rnorm, overIndicator);
-                imagedata.channel.red = imagedata.channel.green = imagedata.channel.blue = nGray;
-                }
-            else
-                {
-                imagedata.channel.red   = MixPixel (rrGain, rgGain, rbGain, red, green, blue, rnorm, overIndicator);
-                imagedata.channel.green = MixPixel (grGain, ggGain, gbGain, red, green, blue, gnorm, overIndicator);
-                imagedata.channel.blue  = MixPixel (brGain, bgGain, bbGain, red, green, blue, bnorm, overIndicator);
-                }
-            
-            data[i] = imagedata.raw;
+            nGray = MixPixel (rrGain, rgGain, rbGain, red, green, blue, rnorm, overIndicator);
+            imagedata.channel.red = imagedata.channel.green = imagedata.channel.blue = nGray;
             }
+        else
+            {
+            imagedata.channel.red   = MixPixel (rrGain, rgGain, rbGain, red, green, blue, rnorm, overIndicator);
+            imagedata.channel.green = MixPixel (grGain, ggGain, gbGain, red, green, blue, gnorm, overIndicator);
+            imagedata.channel.blue  = MixPixel (brGain, bgGain, bbGain, red, green, blue, bnorm, overIndicator);
+            }
+        
+        data[i] = imagedata.raw;
         }
 }
 
@@ -833,9 +659,10 @@ void ImageFilters::changeTonality(uint *data, int width, int height, int redMask
        return;
        }
 
-    int       red, green , blue;
     int       hue, sat, lig;
     float     gray;
+    
+    int       red, green, blue;
     imageData imagedata;
     
     hue = redMask;
@@ -871,7 +698,8 @@ void ImageFilters::changeTonality(uint *data, int width, int height, int redMask
 }
 
 //////////////////////////////////////////////////////////////////////////////
-/* Function to apply the sharpen filter on an image
+/* Function to apply the sharpen filter on an image. This method do not use a 
+ * dedicaced thread.
  *
  * data             => The image data in RGBA mode.  
  * w                => Width of image.                          
@@ -888,164 +716,17 @@ void ImageFilters::sharpenImage(uint* data, int w, int h, int r)
                    << endl;
        return;
        }
-    
-    // initialize the LUTs
 
-    int fact = 100 - r;
-    if (fact < 1)
-        fact = 1;
+    if (r > 100) r = 100;
+    if (r <= 0) return;
 
-    int negLUT[256];
-    int posLUT[256];
-    
-    for (int i = 0; i < 256; i++)
-    {
-        posLUT[i] = 800 * i / fact;
-        negLUT[i] = (4 + posLUT[i] - (i << 3)) >> 3;
-    }
+    QImage orgImage(w, h, 32);
+    memcpy( orgImage.bits(), data, orgImage.numBytes() );
 
-    unsigned int* dstData = new unsigned int[w*h];
-    
-    // work with four rows at one time
-
-    unsigned char* src_rows[4];
-    unsigned char* src_ptr;
-    unsigned char* dst_row;
-    int*           neg_rows[4]; 
-    int*           neg_ptr;
-    int            row;
-    int            count;
-
-    int  width = sizeof(unsigned int)*w;
-
-    for (row = 0; row < 4; row++)
-    {
-        src_rows[row] = new unsigned char[width];
-        neg_rows[row] = new int[width];
-    }       
-
-    dst_row = new unsigned char[width];
-    
-    // Pre-load the first row for the filter...
-
-    memcpy(src_rows[0], data, width); 
-
-    int i;
-    for ( i = width, src_ptr = src_rows[0], neg_ptr = neg_rows[0];
-         i > 0;
-         i--, src_ptr++, neg_ptr++)
-        *neg_ptr = negLUT[*src_ptr]; 
-
-    row   = 1;
-    count = 1;                                    
-
-    for (int y = 0; y < h; y++)
-    {
-        // Load the next pixel row...
-
-        if ((y + 1) < h)
-        {
-            
-            // Check to see if our src_rows[] array is overflowing yet...
-
-            if (count >= 3)
-                count--;
-
-            // Grab the next row...
-
-            memcpy(src_rows[row], data + y*w, width); 
-            for (i = width, src_ptr = src_rows[row], neg_ptr = neg_rows[row];
-                 i > 0;
-                 i--, src_ptr++, neg_ptr++)
-                *neg_ptr = negLUT[*src_ptr];
-
-            count++;
-            row = (row + 1) & 3;
-        }
-
-        else
-        {
-            // No more pixels at the bottom...  Drop the oldest samples...
-
-            count--;
-        }
-
-        // Now sharpen pixels and save the results...
-
-        if (count == 3)
-        {
-            uchar* src  = src_rows[(row + 2) & 3];
-            uchar* dst  = dst_row;
-            int*   neg0 = neg_rows[(row + 1) & 3] + 4;
-            int*   neg1 = neg_rows[(row + 2) & 3] + 4;
-            int*   neg2 = neg_rows[(row + 3) & 3] + 4;
-            
-            // New pixel value 
-            int pixel;         
-
-            int wm = w;
-            
-            *dst++ = *src++;
-            *dst++ = *src++;
-            *dst++ = *src++;
-            *dst++ = *src++;
-            wm -= 2;
-
-            while (wm > 0)
-            {
-                pixel = (posLUT[*src++] - neg0[-4] - neg0[0] - neg0[4] -
-                         neg1[-4] - neg1[4] -
-                         neg2[-4] - neg2[0] - neg2[4]);
-                pixel = (pixel + 4) >> 3;
-                *dst++ = CLAMP0255 (pixel);
-
-                pixel = (posLUT[*src++] - neg0[-3] - neg0[1] - neg0[5] -
-                         neg1[-3] - neg1[5] -
-                         neg2[-3] - neg2[1] - neg2[5]);
-                pixel = (pixel + 4) >> 3;
-                *dst++ = CLAMP0255 (pixel);
-
-                pixel = (posLUT[*src++] - neg0[-2] - neg0[2] - neg0[6] -
-                         neg1[-2] - neg1[6] -
-                         neg2[-2] - neg2[2] - neg2[6]);
-                pixel = (pixel + 4) >> 3;
-                *dst++ = CLAMP0255 (pixel);
-
-                *dst++ = *src++;
-
-                neg0 += 4;
-                neg1 += 4;
-                neg2 += 4;
-                wm --;
-            }
-
-            *dst++ = *src++;
-            *dst++ = *src++;
-            *dst++ = *src++;
-            *dst++ = *src++;
-            
-            
-            // Set the row...
-            memcpy(dstData + y*w, dst_row, width); 
-        }
-        else if (count == 2)
-        {
-            if (y == 0)
-            {
-                // first row 
-                memcpy(dstData + y*w, src_rows[0], width);
-            }
-            else
-            {
-                // last row 
-                memcpy(dstData + y*w, src_rows[(h-1) & 3], width);
-            }
-        }
-
-    }
-
-    memcpy(data, dstData, w*h*sizeof(uint));
-    delete [] dstData;
+    Digikam::Sharpen *threadedFilter = new Digikam::Sharpen(&orgImage, 0L, r);
+    QImage imDest = threadedFilter->getTargetImage();
+    memcpy( data, imDest.bits(), imDest.numBytes() );
+    delete threadedFilter;
 }
 
 void ImageFilters::hueSaturationLightnessImage(uint* data, int w, int h, double hu, double sa, double li)
@@ -1059,9 +740,9 @@ void ImageFilters::hueSaturationLightnessImage(uint* data, int w, int h, double
     
     // Calculate HSL Transfers.
 
-    int value;
+    int          value;
     register int i;
-    HSLParam hsl;
+    HSLParam     hsl;
     
     for (i = 0; i < 256; i++)
        {
@@ -1099,33 +780,83 @@ void ImageFilters::hueSaturationLightnessImage(uint* data, int w, int h, double
        }
         
     // Apply HSL.
-    uchar* c;
-    int r, g, b;
-
-    unsigned int* ptr = data;
-
-    for (i = 0 ; i < w*h ; i++) 
+    
+    int       red, green, blue;
+    imageData imagedata;
+    
+    for (int i = 0; i < w*h; i++) 
        {
-       c = (unsigned char*) ptr;
-
-       b = c[0];
-       g = c[1];
-       r = c[2];
-
-       Digikam::rgb_to_hsl(r, g, b);
+       imagedata.raw = data[i];
+       red           = (int)imagedata.channel.red;
+       green         = (int)imagedata.channel.green;
+       blue          = (int)imagedata.channel.blue;
+        
+       Digikam::rgb_to_hsl(red, green, blue);
          
-       r = hsl.htransfer[r];
-       g = hsl.stransfer[g];
-       b = hsl.ltransfer[b];
+       red   = hsl.htransfer[red];
+       green = hsl.stransfer[green];
+       blue  = hsl.ltransfer[blue];
 
-       Digikam::hsl_to_rgb (r, g, b);
-
-       c[0] = b;
-       c[1] = g;
-       c[2] = r;
-
-       ptr++;
+       Digikam::hsl_to_rgb(red, green, blue);
+        
+       imagedata.channel.red   = (uchar)red;
+       imagedata.channel.green = (uchar)green;
+       imagedata.channel.blue  = (uchar)blue;
+       data[i] = imagedata.raw;
        }
 }
+
+//////////////////////////////////////////////////////////////////////////////
+/* Function to perform pixel antialiasing.
+ *
+ * data             => The original image data in RGBA mode.  
+ * w                => Width of image.                          
+ * h                => Height of image.                            
+ * X                => x position of pixel.                                         
+ * Y                => x position of pixel.                                         
+ * A, R, G, B       => RGBA color component result of pixel aliased.
+ *                                                                                 
+ * Theory           => this method is used to smooth target image in transformation 
+ *                     method like free rotation.  
+ */
+void ImageFilters::pixelAntiAliasing (uchar *data, int Width, int Height, double X, double Y, 
+                                             uchar *A, uchar *R, uchar *G, uchar *B)
+{
+    int nX, nY, j;
+    double lfWeightX[2], lfWeightY[2], lfWeight;
+    double lfTotalR = 0.0, lfTotalG = 0.0, lfTotalB = 0.0, lfTotalA = 0.0;
+
+    nX = (int)X;
+    nY = (int)Y;
+
+    if (Y >= 0.0)
+        lfWeightY[0] = 1.0 - (lfWeightY[1] = Y - (double)nY);
+    else
+        lfWeightY[1] = 1.0 - (lfWeightY[0] = -(Y - (double)nY));
+
+    if (X >= 0.0)
+        lfWeightX[0] = 1.0 - (lfWeightX[1] = X - (double)nX);
+    else
+        lfWeightX[1] = 1.0 - (lfWeightX[0] = -(X - (double)nX));
+
+    for (int loopx = 0; loopx <= 1; loopx++)
+        {
+        for (int loopy = 0; loopy <= 1; loopy++)
+            {
+            lfWeight = lfWeightX[loopx] * lfWeightY[loopy];
+            j = setPositionAdjusted (Width, Height, nX + loopx, nY + loopy);
+
+            lfTotalB += ((double)data[j++] * lfWeight);
+            lfTotalG += ((double)data[j++] * lfWeight);
+            lfTotalR += ((double)data[j++] * lfWeight);
+            lfTotalA += ((double)data[j++] * lfWeight);
+            }
+        }
+         
+    *B = CLAMP0255 ((int)lfTotalB);
+    *G = CLAMP0255 ((int)lfTotalG);
+    *R = CLAMP0255 ((int)lfTotalR);
+    *A = CLAMP0255 ((int)lfTotalA);
+}
        
 }  // NameSpace Digikam
