@@ -3,7 +3,7 @@
  * Date  : 2004-08-22
  * Description : 
  * 
- * Copyright 2004 by Gilles Caulier
+ * Copyright 2004-2005 by Gilles Caulier
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -44,6 +44,7 @@
 // Local includes.
 
 #include "imagepaniconwidget.h"
+#include "imageregionwidget.h"
 
 namespace Digikam
 {
@@ -52,6 +53,7 @@ ImagePanIconWidget::ImagePanIconWidget(int w, int h, QWidget *parent)
                   : QWidget(parent, 0, Qt::WDestructiveClose)
 {
     m_moveSelection = false;
+    m_separateView  = Digikam::ImageRegionWidget::SeparateViewVertical;
     m_iface  = new ImageIface(w,h);
 
     m_data   = m_iface->getPreviewData();
@@ -107,31 +109,31 @@ void ImagePanIconWidget::setCenterSelection(void)
              m_regionSelection.height()));
 }
 
+void ImagePanIconWidget::setHighLightPoints(QPointArray pointsList)
+{
+    m_hightlightPoints = pointsList;
+    updatePixmap();
+    repaint(false);
+}
+       
 void ImagePanIconWidget::regionSelectionMoved( bool targetDone )
 {
     if (targetDone)
        {
-       if (m_localRegionSelection.left() < 0) m_localRegionSelection.moveLeft(0);
-       if (m_localRegionSelection.top() < 0) m_localRegionSelection.moveTop(0);
-       if (m_localRegionSelection.right() > m_rect.width())
-          m_localRegionSelection.moveRight(m_rect.width());
-       if (m_localRegionSelection.bottom() > m_rect.height()) 
-          m_localRegionSelection.moveBottom(m_rect.height());
-       
        updatePixmap();          
        repaint(false);
        }
     
-    int x = (int)( ((float)m_localRegionSelection.x() - (float)m_rect.x() ) * 
+    int x = ROUND( ((float)m_localRegionSelection.x() - (float)m_rect.x() ) * 
                    ( (float)m_iface->originalWidth() / (float)m_w ));
                                             
-    int y = (int)( ((float)m_localRegionSelection.y() - (float)m_rect.y() ) *
+    int y = ROUND( ((float)m_localRegionSelection.y() - (float)m_rect.y() ) *
                    ( (float)m_iface->originalHeight() / (float)m_h ));
                                             
-    int w = (int)((float)m_localRegionSelection.width() *
+    int w = ROUND((float)m_localRegionSelection.width() *
                  ( (float)m_iface->originalWidth() / (float)m_w ));
                                      
-    int h = (int)((float)m_localRegionSelection.height() *
+    int h = ROUND((float)m_localRegionSelection.height() *
                  ( (float)m_iface->originalHeight() / (float)m_h ));
                      
     m_regionSelection.setX(x);
@@ -146,15 +148,66 @@ void ImagePanIconWidget::updatePixmap( void )
 {
     // Drawing background and image.
     m_pixmap->fill(colorGroup().background());
-    m_iface->paint(m_pixmap, m_rect.x(), m_rect.y(),
-                   m_rect.width(), m_rect.height());
+    m_iface->paint(m_pixmap, m_rect.x(), m_rect.y(), m_rect.width(), m_rect.height());
     
     QPainter p(m_pixmap);
+   
+    // Drawing HighLighted points.
+    
+    if (!m_hightlightPoints.isEmpty())
+       {
+       QPoint pt;
+       
+       for (uint i = 0 ; i < m_hightlightPoints.count() ; i++)
+          {
+          pt = m_hightlightPoints.point(i);
+          pt.setX((int)(pt.x() * (float)(m_w)/(float)m_iface->originalWidth()));
+          pt.setY((int)(pt.y() * (float)(m_h)/(float)m_iface->originalHeight()));
+          p.setPen(QPen(Qt::black, 1, Qt::SolidLine));
+          p.drawLine(pt.x(), pt.y()-1, pt.x(), pt.y()+1);
+          p.drawLine(pt.x()-1, pt.y(), pt.x()+1, pt.y());
+          p.setPen(QPen(Qt::white, 1, Qt::SolidLine));
+          p.drawPoint(pt.x()-1, pt.y()-1);
+          p.drawPoint(pt.x()+1, pt.y()+1);
+          p.drawPoint(pt.x()-1, pt.y()+1);
+          p.drawPoint(pt.x()+1, pt.y()-1);
+          }
+       }   
     
     // Drawing selection border
-    p.setPen(QPen(Qt::red, 2, Qt::SolidLine));
+    p.setPen(QPen(Qt::white, 1, Qt::SolidLine));
     p.drawRect(m_localRegionSelection);
+    p.setPen(QPen(Qt::red, 1, Qt::SolidLine));
+    p.drawRect(m_localRegionSelection.x()+1, m_localRegionSelection.y()+1,
+               m_localRegionSelection.width()-2, m_localRegionSelection.height()-2);
     
+    if (m_separateView == Digikam::ImageRegionWidget::SeparateViewVertical)
+        {
+        p.setPen(QPen(Qt::white, 1, Qt::SolidLine));
+        p.drawLine(m_localRegionSelection.topLeft().x() + m_localRegionSelection.width()/2,
+                   m_localRegionSelection.topLeft().y(),
+                   m_localRegionSelection.bottomLeft().x() + m_localRegionSelection.width()/2,
+                   m_localRegionSelection.bottomLeft().y());
+        p.setPen(QPen(Qt::red, 1, Qt::DotLine));
+        p.drawLine(m_localRegionSelection.topLeft().x() + m_localRegionSelection.width()/2,
+                   m_localRegionSelection.topLeft().y()+1,
+                   m_localRegionSelection.bottomLeft().x() + m_localRegionSelection.width()/2,
+                   m_localRegionSelection.bottomLeft().y()-1);
+        }
+    else if (m_separateView == Digikam::ImageRegionWidget::SeparateViewHorizontal)
+        {
+        p.setPen(QPen(Qt::white, 1, Qt::SolidLine));
+        p.drawLine(m_localRegionSelection.topLeft().x(),
+                   m_localRegionSelection.topLeft().y() + m_localRegionSelection.height()/2,
+                   m_localRegionSelection.topRight().x(),
+                   m_localRegionSelection.topRight().y() + m_localRegionSelection.height()/2);
+        p.setPen(QPen(Qt::red, 1, Qt::DotLine));
+        p.drawLine(m_localRegionSelection.topLeft().x()+1,
+                   m_localRegionSelection.topLeft().y() + m_localRegionSelection.height()/2,
+                   m_localRegionSelection.topRight().x()-1,
+                   m_localRegionSelection.topRight().y() + m_localRegionSelection.height()/2);
+        }
+
     p.end();
 }
 
@@ -171,15 +224,16 @@ void ImagePanIconWidget::mousePressEvent ( QMouseEvent * e )
        m_xpos = e->x();
        m_ypos = e->y();
        m_moveSelection = true;
-       setCursor ( KCursor::sizeAllCursor() );
+       setCursor( KCursor::sizeAllCursor() );           
+       emit signalSelectionTakeFocus();
        }
 }
 
 void ImagePanIconWidget::mouseReleaseEvent ( QMouseEvent * )
 {
-    if ( m_moveSelection && m_localRegionSelection.contains( m_xpos, m_ypos ) ) 
+    if ( m_moveSelection ) 
        {    
-       setCursor ( KCursor::arrowCursor() );
+       setCursor( KCursor::arrowCursor() );           
        regionSelectionMoved(true);
        m_moveSelection = false;
        }
@@ -191,25 +245,47 @@ void ImagePanIconWidget::mouseMoveEvent ( QMouseEvent * e )
        {
        int newxpos = e->x();
        int newypos = e->y();
-       
+
        m_localRegionSelection.moveBy (newxpos - m_xpos, newypos - m_ypos);
-       updatePixmap();
-       repaint(false);
      
        m_xpos = newxpos;
        m_ypos = newypos;
+              
+       // Perform normalization of selection area.
+          
+       if (m_localRegionSelection.left() < m_rect.left()) 
+          m_localRegionSelection.moveLeft(m_rect.left());
+            
+       if (m_localRegionSelection.top() < m_rect.top()) 
+          m_localRegionSelection.moveTop(m_rect.top());
+            
+       if (m_localRegionSelection.right() > m_rect.right())
+          m_localRegionSelection.moveRight(m_rect.right());
+            
+       if (m_localRegionSelection.bottom() > m_rect.bottom()) 
+          m_localRegionSelection.moveBottom(m_rect.bottom());
+       
+       updatePixmap();
+       repaint(false);
        regionSelectionMoved(false);
        return;
        }        
     else 
        {
        if ( m_localRegionSelection.contains( e->x(), e->y() ) )
-           setCursor( KCursor::handCursor() );
+           setCursor( KCursor::handCursor() );           
        else
-           setCursor( KCursor::arrowCursor() );
+           setCursor( KCursor::arrowCursor() );           
        }
 }
 
+void ImagePanIconWidget::slotSeparateViewToggled(int t)
+{
+    m_separateView = t;
+    updatePixmap();
+    repaint(false);
+}
+
 }  // NameSpace Digikam
 
 #include "imagepaniconwidget.moc"
