@@ -32,21 +32,25 @@
 #include <qlabel.h>
 #include <qwhatsthis.h>
 #include <qgroupbox.h>
+#include <qhbuttongroup.h> 
+#include <qpushbutton.h>
+#include <qtooltip.h>
 
 // KDE includes.
 
+#include <kstandarddirs.h>
 #include <kurl.h>
 #include <klocale.h>
 #include <kapplication.h>
 #include <kconfig.h>
 #include <kfileitem.h>
-#include <kio/previewjob.h>
 
 // Local includes.
 
 #include "imagehistogram.h"
 #include "histogramwidget.h"
 #include "colorgradientwidget.h"
+#include "thumbnailjob.h"
 #include "imagepropertieshistogram.h"
 
 ImagePropertiesHistogram::ImagePropertiesHistogram(QWidget* page, QRect* selectionArea)
@@ -81,16 +85,31 @@ ImagePropertiesHistogram::ImagePropertiesHistogram(QWidget* page, QRect* selecti
                                        "is supported by some image formats such as PNG or GIF.<p>"
                                        "<b>Colors</b>: drawing all color channels values at the same time."));
     
-    QLabel *label2 = new QLabel(i18n("Scale:"), page);
-    label2->setAlignment ( Qt::AlignRight | Qt::AlignVCenter);
-    m_scaleCB = new QComboBox( false, page );
-    m_scaleCB->insertItem( i18n("Linear") );
-    m_scaleCB->insertItem( i18n("Logarithmic") );
-    QWhatsThis::add( m_scaleCB, i18n("<p>Select here the histogram scale.<p>"
-                                     "If the image maximal counts is small, you can use the linear scale.<p>"
-                                     "Logarithmic scale can be used when the maximal counts is big. "
-                                     "Like this all values (small and big) will be visible on the graph."));
+    m_scaleBG = new QHButtonGroup(page);
+    m_scaleBG->setExclusive(true);
+    m_scaleBG->setFrameShape(QFrame::NoFrame);
+    m_scaleBG->setInsideMargin( 0 );
+    QWhatsThis::add( m_scaleBG, i18n("<p>Select here the histogram scale.<p>"
+                                     "If the image's maximal counts are small, you can use the linear scale.<p>"
+                                     "Logarithmic scale can be used when the maximal counts are big; "
+                                     "if it is used, all values (small and large) will be visible on the graph."));
     
+    QPushButton *linHistoButton = new QPushButton( m_scaleBG );
+    QToolTip::add( linHistoButton, i18n( "<p>Linear" ) );
+    m_scaleBG->insert(linHistoButton, Digikam::HistogramWidget::LinScaleHistogram);
+    KGlobal::dirs()->addResourceType("histogram-lin", KGlobal::dirs()->kde_default("data") + "digikam/data");
+    QString directory = KGlobal::dirs()->findResourceDir("histogram-lin", "histogram-lin.png");
+    linHistoButton->setPixmap( QPixmap( directory + "histogram-lin.png" ) );
+    linHistoButton->setToggleButton(true);
+    
+    QPushButton *logHistoButton = new QPushButton( m_scaleBG );
+    QToolTip::add( logHistoButton, i18n( "<p>Logarithmic" ) );
+    m_scaleBG->insert(logHistoButton, Digikam::HistogramWidget::LogScaleHistogram);
+    KGlobal::dirs()->addResourceType("histogram-log", KGlobal::dirs()->kde_default("data") + "digikam/data");
+    directory = KGlobal::dirs()->findResourceDir("histogram-log", "histogram-log.png");
+    logHistoButton->setPixmap( QPixmap( directory + "histogram-log.png" ) );
+    logHistoButton->setToggleButton(true);       
+        
     QLabel *label10 = new QLabel(i18n("Colors:"), page);
     label10->setAlignment ( Qt::AlignRight | Qt::AlignVCenter );
     m_colorsCB = new QComboBox( false, page );
@@ -103,39 +122,48 @@ ImagePropertiesHistogram::ImagePropertiesHistogram(QWidget* page, QRect* selecti
                                        "<b>Green</b>: drawing the green image channel on the foreground.<p>"
                                        "<b>Blue</b>: drawing the blue image channel on the foreground.<p>"));
                                        
-    m_labelRendering = new QLabel(i18n("Rendering:"), page);
-    m_labelRendering->setAlignment ( Qt::AlignRight | Qt::AlignVCenter );
-    m_renderingCB = new QComboBox( false, page );
-    m_renderingCB->insertItem( i18n("Full Image") );
-    m_renderingCB->insertItem( i18n("Selection") );
+    m_regionBG = new QHButtonGroup(page);
+    m_regionBG->setExclusive(true);
+    m_regionBG->setFrameShape(QFrame::NoFrame);
+    m_regionBG->setInsideMargin( 0 );
+    m_regionBG->hide();
+    QWhatsThis::add( m_regionBG, i18n("<p>Select here the histogram region computation:<p>"
+                                      "<b>Full Image</b>: drawing histogram using the full image.<p>"
+                                      "<b>Selection</b>: drawing histogram using the current image selection."));
     
-    QWhatsThis::add( m_renderingCB, i18n("<p>Select here the histogram rendering method:<p>"
-                     "<b>Full Image</b>: drawing histogram using the full image.<p>"
-                     "<b>Selection</b>: drawing histogram using the current image selection."));  
-                                                                            
+    QPushButton *fullImageButton = new QPushButton( m_regionBG );
+    QToolTip::add( fullImageButton, i18n( "<p>Full Image" ) );
+    m_regionBG->insert(fullImageButton, Digikam::HistogramWidget::FullImageHistogram);
+    KGlobal::dirs()->addResourceType("image-full", KGlobal::dirs()->kde_default("data") + "digikam/data");
+    directory = KGlobal::dirs()->findResourceDir("image-full", "image-full.png");
+    fullImageButton->setPixmap( QPixmap( directory + "image-full.png" ) );
+    fullImageButton->setToggleButton(true);
+    
+    QPushButton *SelectionImageButton = new QPushButton( m_regionBG );
+    QToolTip::add( SelectionImageButton, i18n( "<p>Selection" ) );
+    m_regionBG->insert(SelectionImageButton, Digikam::HistogramWidget::ImageSelectionHistogram);
+    KGlobal::dirs()->addResourceType("image-selection", KGlobal::dirs()->kde_default("data") + "digikam/data");
+    directory = KGlobal::dirs()->findResourceDir("image-selection", "image-selection.png");
+    SelectionImageButton->setPixmap( QPixmap( directory + "image-selection.png" ) );
+    SelectionImageButton->setToggleButton(true);       
+                                                                                
     grid->addWidget(label1, 0, 0);
     grid->addWidget(m_channelCB, 0, 1);
-    grid->addWidget(label2, 0, 2);
-    grid->addWidget(m_scaleCB, 0, 3);
+    grid->addWidget(m_scaleBG, 0, 2);
     grid->addWidget(label10, 1, 0);
     grid->addWidget(m_colorsCB, 1, 1);
-    grid->addWidget(m_labelRendering, 1, 2);
-    grid->addWidget(m_renderingCB, 1, 3);
+    grid->addWidget(m_regionBG, 1, 2);
     
     // -------------------------------------------------------------
     
-    QFrame *frame = new QFrame( page );
-    frame->setFrameStyle(QFrame::Panel|QFrame::Sunken);
-    QVBoxLayout* l = new QVBoxLayout(frame, 5, 0);
-    
-    m_histogramWidget = new Digikam::HistogramWidget(256, 140, frame);
+    m_histogramWidget = new Digikam::HistogramWidget(256, 140, page);
     QWhatsThis::add( m_histogramWidget, i18n("<p>This is the histogram drawing of the "
                                              "selected image channel"));
-    l->addWidget(m_histogramWidget, 0);
         
-    m_hGradient = new Digikam::ColorGradientWidget( KSelector::Horizontal, 20, page );
+    m_hGradient = new Digikam::ColorGradientWidget( Digikam::ColorGradientWidget::Horizontal, 10, page );
     m_hGradient->setColors( QColor( "black" ), QColor( "white" ) );
-    topLayout->addWidget(frame, 4);
+    
+    topLayout->addWidget(m_histogramWidget, 4);
     topLayout->addWidget(m_hGradient, 0);
 
     // -------------------------------------------------------------
@@ -200,14 +228,14 @@ ImagePropertiesHistogram::ImagePropertiesHistogram(QWidget* page, QRect* selecti
     connect(m_channelCB, SIGNAL(activated(int)),
             this, SLOT(slotChannelChanged(int)));
     
-    connect(m_scaleCB, SIGNAL(activated(int)),
+    connect(m_scaleBG, SIGNAL(released(int)),
             this, SLOT(slotScaleChanged(int)));
     
     connect(m_colorsCB, SIGNAL(activated(int)),
             this, SLOT(slotColorsChanged(int)));     
                    
-    connect(m_renderingCB, SIGNAL(activated(int)),
-            this, SLOT(slotRenderingChanged(int)));       
+    connect(m_regionBG, SIGNAL(released(int)),
+            this, SLOT(slotRenderingChanged(int))); ;       
              
     connect(m_histogramWidget, SIGNAL(signalMousePressed( int )),
             this, SLOT(slotUpdateMinInterv(int)));
@@ -235,9 +263,9 @@ ImagePropertiesHistogram::ImagePropertiesHistogram(QWidget* page, QRect* selecti
     KConfig* config = kapp->config();
     config->setGroup("Image Properties Dialog");
     m_channelCB->setCurrentItem(config->readNumEntry("Histogram Channel", 0));    // Luminosity.
-    m_scaleCB->setCurrentItem(config->readNumEntry("Histogram Scale", 0));        // Linear.
+    m_scaleBG->setButton(config->readNumEntry("Histogram Scale", Digikam::HistogramWidget::LinScaleHistogram)); 
     m_colorsCB->setCurrentItem(config->readNumEntry("Histogram Color", 0));       // Red.
-    m_renderingCB->setCurrentItem(config->readNumEntry("Histogram Rendering", 0));// Full image.
+    m_regionBG->setButton(config->readNumEntry("Histogram Rendering", Digikam::HistogramWidget::FullImageHistogram));
 }
 
 ImagePropertiesHistogram::~ImagePropertiesHistogram()
@@ -249,10 +277,13 @@ ImagePropertiesHistogram::~ImagePropertiesHistogram()
     KConfig* config = kapp->config();
     config->setGroup("Image Properties Dialog");
     config->writeEntry("Histogram Channel", m_channelCB->currentItem());
-    config->writeEntry("Histogram Scale", m_scaleCB->currentItem());
+    config->writeEntry("Histogram Scale", m_scaleBG->selectedId());
     config->writeEntry("Histogram Color", m_colorsCB->currentItem());
-    config->writeEntry("Histogram Rendering", m_renderingCB->currentItem());
+    config->writeEntry("Histogram Rendering", m_regionBG->selectedId());
     
+    if (!m_thumbJob.isNull())
+        m_thumbJob->kill();
+        
     if ( m_histogramWidget )
        delete m_histogramWidget;
     
@@ -262,12 +293,21 @@ ImagePropertiesHistogram::~ImagePropertiesHistogram()
 
 void ImagePropertiesHistogram::setData(const KURL& url, uint* imageData, int imageWidth, int imageHeight)
 {
-    KIO::PreviewJob* job = KIO::filePreview(url, 48);
+    if (!m_thumbJob.isNull())
+    {
+        m_thumbJob->kill();
+        m_thumbJob = 0;
+    }
+
+    m_thumbJob = new ThumbnailJob(url, 48, true);
     
-    connect(job, SIGNAL(gotPreview(const KFileItem *, const QPixmap &)),
-            this, SLOT(slotGotThumbnail(const KFileItem *, const QPixmap &)));
-    connect(job, SIGNAL(failed(const KFileItem *)),
-            this, SLOT(slotFailedThumbnail(const KFileItem *)));
+    connect(m_thumbJob, SIGNAL(signalThumbnail(const KURL&,
+                                               const QPixmap&)),
+            SLOT(slotGotThumbnail(const KURL&,
+                                  const QPixmap&)));
+   
+    connect(m_thumbJob, SIGNAL(signalFailed(const KURL&)),
+            SLOT(slotFailedThumbnail(const KURL&)));    
             
     // ----------------------------------------------------------------
 
@@ -292,14 +332,12 @@ void ImagePropertiesHistogram::setData(const KURL& url, uint* imageData, int ima
                 m_histogramWidget->updateData((uint *)m_image.bits(), m_image.width(), m_image.height(),
                                               (uint *)m_imageSelection.bits(), m_imageSelection.width(),
                                               m_imageSelection.height());
-                m_labelRendering->show();                                         
-                m_renderingCB->show();                                         
+                m_regionBG->show();                                         
             }
             else 
             {
                 m_histogramWidget->updateData((uint *)m_image.bits(), m_image.width(), m_image.height());
-                m_labelRendering->hide();                                         
-                m_renderingCB->hide();
+                m_regionBG->hide();
             }
         }
         else 
@@ -324,14 +362,12 @@ void ImagePropertiesHistogram::setData(const KURL& url, uint* imageData, int ima
                 m_histogramWidget->updateData((uint *)m_image.bits(), m_image.width(), m_image.height(),
                                               (uint *)m_imageSelection.bits(), m_imageSelection.width(),
                                               m_imageSelection.height());
-                m_labelRendering->show();                                         
-                m_renderingCB->show();                                         
+                m_regionBG->show();                                         
             }
             else 
             {
                 m_histogramWidget->updateData((uint *)m_image.bits(), m_image.width(), m_image.height());
-                m_labelRendering->hide();                                         
-                m_renderingCB->hide();
+                m_regionBG->hide();
             }
         }
         else 
@@ -345,11 +381,11 @@ void ImagePropertiesHistogram::setData(const KURL& url, uint* imageData, int ima
 void ImagePropertiesHistogram::slotRefreshOptions()
 {
     slotChannelChanged(m_channelCB->currentItem());
-    slotScaleChanged(m_scaleCB->currentItem());
+    slotScaleChanged(m_scaleBG->selectedId());
     slotColorsChanged(m_colorsCB->currentItem());
     
     if (m_selectionArea)
-       slotRenderingChanged(m_renderingCB->currentItem());
+       slotRenderingChanged(m_regionBG->selectedId());
 }
 
 void ImagePropertiesHistogram::slotChannelChanged(int channel)
@@ -399,17 +435,7 @@ void ImagePropertiesHistogram::slotChannelChanged(int channel)
 
 void ImagePropertiesHistogram::slotScaleChanged(int scale)
 {
-    switch(scale)
-    {
-    case 1:           // Log.
-        m_histogramWidget->m_scaleType = Digikam::HistogramWidget::LogScaleHistogram;
-        break;
-          
-    default:          // Lin.
-        m_histogramWidget->m_scaleType = Digikam::HistogramWidget::LinScaleHistogram;
-        break;
-    }
-   
+    m_histogramWidget->m_scaleType = scale;
     m_histogramWidget->repaint(false);
 }
 
@@ -436,17 +462,7 @@ void ImagePropertiesHistogram::slotColorsChanged(int color)
 
 void ImagePropertiesHistogram::slotRenderingChanged(int rendering)
 {
-    switch(rendering)
-    {
-    case 1:           // Image Selection.
-        m_histogramWidget->m_renderingType = Digikam::HistogramWidget::ImageSelectionHistogram;
-        break;
-       
-    default:          // Full Image.
-        m_histogramWidget->m_renderingType = Digikam::HistogramWidget::FullImageHistogram;
-        break;
-    }
-
+    m_histogramWidget->m_renderingType = rendering;
     m_histogramWidget->repaint(false);
     updateInformation();
 }
@@ -498,7 +514,9 @@ void ImagePropertiesHistogram::updateInformation()
     m_labelPercentileValue->setText(value.setNum(percentile, 'f', 1));
 }
 
-void ImagePropertiesHistogram::slotGotThumbnail(const KFileItem *, const QPixmap &pix)
+void ImagePropertiesHistogram::slotGotThumbnail(const KURL&,
+                                                const QPixmap& pix)
+
 {
     if (!pix.isNull())
         m_labelThumb->setPixmap(pix);
@@ -506,7 +524,7 @@ void ImagePropertiesHistogram::slotGotThumbnail(const KFileItem *, const QPixmap
         m_labelThumb->clear();
 }
 
-void ImagePropertiesHistogram::slotFailedThumbnail(const KFileItem *)
+void ImagePropertiesHistogram::slotFailedThumbnail(const KURL&)
 {
     m_labelThumb->clear();
 }
