@@ -40,6 +40,7 @@ class KToolBarPopupAction;
 class Canvas;
 class ImagePluginLoader;
 class SplashScreen;
+class SlideShow;
 
 namespace KIO
 {
@@ -82,6 +83,7 @@ private slots:
     void slotFileProperties();
     
     void slotToggleFullScreen();
+    void slotToggleSlideShow();
     void slotAutoFit();
     void slotZoomChanged(float zoom);
     void slotResize();
@@ -93,6 +95,7 @@ private slots:
     
     void slotChanged(bool, bool);
     void slotSelected(bool);
+    void slotUpdateItemInfo(void);
     
     void slotAboutToShowUndoMenu();
     void slotAboutToShowRedoMenu();
@@ -112,7 +115,8 @@ private:
     void saveSettings();
     bool promptUserSave();
     bool save();
-    void toggleActions(bool val);
+    void toggleActions(bool val, bool slideShow=false);
+    void toggleNavigation(int index);
     void loadPlugins();
     void unLoadPlugins();
 
@@ -127,6 +131,8 @@ private:
     
     SplashScreen          *m_splash;
     
+    SlideShow             *m_slideShow;
+                          
     QLabel                *m_nameLabel;
     QLabel                *m_zoomLabel;
     QLabel                *m_resLabel;
@@ -140,6 +146,7 @@ private:
     KToggleAction         *m_zoomFitAction;
     KToggleAction         *m_fullScreenAction;
     KToggleAction         *m_showBarAction;
+    KToggleAction         *m_slideShowAction;
     
     KAction               *m_cropAction;
     KAction               *m_imagePluginsHelpAction;
@@ -150,6 +157,7 @@ private:
     KAction               *m_propertiesAction;
     KAction               *m_filePrintAction;    
     KAction               *m_fileDeleteAction;
+    KAction               *m_fileOpenAction;
     
     KAction               *m_forwardAction;
     KAction               *m_backAction;
@@ -176,13 +184,15 @@ private:
     
     int                    m_JPEGCompression;
     int                    m_PNGCompression;
+    int                    m_itemsNb;
     
+    bool                   m_removeFullScreenButton;
     bool                   m_fullScreen;
     bool                   m_TIFFCompression;
     bool                   m_fullScreenHideToolBar;
     bool                   m_fullScreenHideThumbBar;
     bool                   m_deleteItem2Trash;
-    bool                   m_disableBCGActions;
+    bool                   m_slideShowInFullScreen;
 };
 
 #endif /* SHOWFOTO_H */
