@@ -20,7 +20,7 @@
 
 #include <qpainter.h>
 #include <qpixmap.h>
-#include <thumbview.h>
+#include <iconview.h>
 
 #include "gpiteminfo.h"
 #include "cameraiconitem.h"
@@ -53,14 +53,16 @@ const char* CameraIconViewItem::new_xpm[] =
 
 QPixmap* CameraIconViewItem::m_newEmblem = 0;
 
-CameraIconViewItem::CameraIconViewItem(ThumbView* parent,
+CameraIconViewItem::CameraIconViewItem(IconGroupItem* parent,
                                        const GPItemInfo& itemInfo,
                                        const QPixmap& pix,
                                        const QString& downloadName)
-    : ThumbItem(parent, itemInfo.name, pix)
+    : IconItem(parent)
 {
     m_itemInfo     = new GPItemInfo(itemInfo);
     m_downloadName = downloadName;
+    m_pixmap       = pix;
+
     calcRect();
 }
 
@@ -69,84 +71,28 @@ CameraIconViewItem::~CameraIconViewItem()
     delete m_itemInfo;
 }
 
-void CameraIconViewItem::calcRect()
+void CameraIconViewItem::setPixmap(const QPixmap& pixmap)
 {
-    const int thumbSize = 128;
-    
-    QRect itemPixRect       = QRect(0,0,0,0);
-    QRect itemTextRect      = QRect(0,0,0,0);
-    QRect itemExtraTextRect = QRect(0,0,0,0);
-    QRect itemRect          = rect();
-
-    itemPixRect.setWidth(thumbSize);
-    itemPixRect.setHeight(thumbSize);
-
-    QFontMetrics fm(iconView()->font());
-    QRect r = QRect(fm.boundingRect(0, 0, thumbSize, 0xFFFFFFFF,
-                                    Qt::AlignHCenter | Qt::AlignTop |
-                                    Qt::WordBreak | Qt::BreakAnywhere,
-                                    m_itemInfo->name));
-    itemTextRect.setWidth(r.width());
-    itemTextRect.setHeight(r.height());
-
-    if (!m_downloadName.isEmpty()) {
-
-        QFont fn(iconView()->font());
-        if (fn.pointSize() > 0)
-        {
-            fn.setPointSize(QMAX(fn.pointSize()-2, 6));
-        }
-
-        fm = QFontMetrics(fn);
-        r = QRect(fm.boundingRect(0, 0, thumbSize, 0xFFFFFFFF,
-                                  Qt::AlignHCenter | Qt::WordBreak |
-                                  Qt::BreakAnywhere | Qt::AlignTop,
-                                  m_downloadName));
-        m_itemExtraRect.setWidth(r.width());
-        m_itemExtraRect.setHeight(r.height());
-
-        itemTextRect.setWidth(QMAX(itemTextRect.width(), m_itemExtraRect.width()));
-        itemTextRect.setHeight(itemTextRect.height() + m_itemExtraRect.height());
-    }
-    
-    int w = QMAX(itemTextRect.width(), itemPixRect.width() );
-    int h = itemTextRect.height() + itemPixRect.height() ;
-
-    itemRect.setWidth(w+4);
-    itemRect.setHeight(h+4);
-
-    // Center the pix and text rect
-    itemPixRect = QRect(2, 2, itemPixRect.width(), itemPixRect.height());
-    itemTextRect = QRect((itemRect.width() - itemTextRect.width())/2,
-                         itemRect.height() - itemTextRect.height(),
-                         itemTextRect.width(), itemTextRect.height());
-    if (!m_itemExtraRect.isEmpty()) {
-        m_itemExtraRect = QRect((itemRect.width() - m_itemExtraRect.width())/2,
-                                itemRect.height() - m_itemExtraRect.height(),
-                                m_itemExtraRect.width(), m_itemExtraRect.height());
-    }
-
-    // Update rects
-    if ( itemPixRect != pixmapRect() )
-        setPixmapRect( itemPixRect );
-    if ( itemTextRect != textRect() )
-        setTextRect( itemTextRect );
-     setRect( itemRect );
+    m_pixmap = pixmap;
 }
 
-void CameraIconViewItem::paintItem(QPainter *, const QColorGroup& cg)
+void CameraIconViewItem::paintItem()
 {
-    QRect pRect=pixmapRect(true);
-    QRect tRect=textRect(true);
-    QFont fn(iconView()->font());
+    IconView* view = iconView();
+    QColorGroup cg = view->colorGroup();
+    QFont fn(view->font());
 
-    QPixmap pix(rect().width(), rect().height());
-    pix.fill(cg.base());
+    QRect r(rect());
+
+    QPixmap pix(r.width(), r.height());
+    pix.fill(isSelected() ? view->colorGroup().highlight() :
+             view->colorGroup().base());
 
     QPainter p(&pix);
-    p.drawPixmap(pRect.x() + (pRect.width()-pixmap()->width())/2,
-                 pRect.y() + (pRect.height()-pixmap()->height())/2,
-                 *pixmap() );
+
+    p.drawPixmap(m_pixRect.x() + (m_pixRect.width() - m_pixmap.width())/2,
+                 m_pixRect.y() + (m_pixRect.height() - m_pixmap.height())/2,
+                 m_pixmap);
 
     if (isSelected())
     {
@@ -154,8 +100,8 @@ void CameraIconViewItem::paintItem(QPainter *, const QColorGroup& cg)
         pen.setColor(cg.highlight());
         p.setPen(pen);
         p.drawRect(0, 0, pix.width(), pix.height());
-        p.fillRect(0, tRect.y(), pix.width(),
-                   tRect.height(), cg.highlight() );
+        p.fillRect(0, m_textRect.y(), pix.width(),
+                   m_textRect.height(), cg.highlight() );
         p.setPen( QPen( cg.highlightedText() ) );
     }
     else
@@ -164,16 +110,17 @@ void CameraIconViewItem::paintItem(QPainter *, const QColorGroup& cg)
         pen.setColor(cg.button());
         p.setPen(pen);
         p.drawRect(0, 0, pix.width(), pix.height());
-        p.fillRect(0, tRect.y(), pix.width(),
-                   tRect.height(), cg.button() );
+        p.fillRect(0, m_textRect.y(), pix.width(),
+                   m_textRect.height(), cg.button() );
         p.setPen( cg.text() );
     }
+    
 
-    p.drawText(tRect, Qt::WordBreak|Qt::BreakAnywhere|
+    p.drawText(m_textRect, Qt::WordBreak|Qt::BreakAnywhere|
                Qt::AlignHCenter|Qt::AlignTop, m_itemInfo->name);
 
-    if (!m_downloadName.isEmpty()) {
-
+    if (!m_downloadName.isEmpty())
+    {
         if (fn.pointSize() > 0)
         {
             fn.setPointSize(QMAX(fn.pointSize()-2, 6));
@@ -182,11 +129,18 @@ void CameraIconViewItem::paintItem(QPainter *, const QColorGroup& cg)
         p.setFont(fn);
         if (!isSelected())
             p.setPen(QPen("steelblue"));
-        p.drawText(m_itemExtraRect, Qt::WordBreak|
+        p.drawText(m_extraRect, Qt::WordBreak|
                    Qt::BreakAnywhere|Qt::AlignHCenter|
                    Qt::AlignTop,m_downloadName);
     }
 
+    if (this == iconView()->currentItem())
+    {
+        p.setPen(QPen(isSelected() ? Qt::white : Qt::black,
+                      1, Qt::DotLine));
+        p.drawRect(0, 0, r.width(), r.height());
+    }
+    
     if (m_itemInfo->downloaded == 0)
     {
         int x = rect().width() - m_newEmblem->width() - 5;
@@ -196,12 +150,10 @@ void CameraIconViewItem::paintItem(QPainter *, const QColorGroup& cg)
     
     p.end();
 
-    QRect r(rect());
-    r = QRect(iconView()->contentsToViewport(QPoint(r.x(), r.y())),
+    r = QRect(view->contentsToViewport(QPoint(r.x(), r.y())),
               QSize(r.width(), r.height()));
 
-    bitBlt(iconView()->viewport(), r.x(), r.y(), &pix,
-           0, 0, r.width()+4, r.height()+4);
+    bitBlt(view->viewport(), r.x(), r.y(), &pix);
 }
 
 void CameraIconViewItem::setDownloadName(const QString& downloadName)
@@ -224,3 +176,84 @@ void CameraIconViewItem::setDownloaded()
         repaint();
     }
 }
+
+void CameraIconViewItem::calcRect()
+{
+    const int thumbSize = 128;
+    
+    m_pixRect       = QRect(0,0,0,0);
+    m_textRect      = QRect(0,0,0,0);
+    m_extraRect     = QRect(0,0,0,0);
+    QRect itemRect  = rect();
+    itemRect.moveTopLeft(QPoint(0,0));
+
+    m_pixRect.setWidth(thumbSize);
+    m_pixRect.setHeight(thumbSize);
+
+    QFontMetrics fm(iconView()->font());
+    QRect r = QRect(fm.boundingRect(0, 0, thumbSize, 0xFFFFFFFF,
+                                    Qt::AlignHCenter | Qt::AlignTop |
+                                    Qt::WordBreak | Qt::BreakAnywhere,
+                                    m_itemInfo->name));
+    m_textRect.setWidth(r.width());
+    m_textRect.setHeight(r.height());
+
+    if (!m_downloadName.isEmpty())
+    {
+        QFont fn(iconView()->font());
+        if (fn.pointSize() > 0)
+        {
+            fn.setPointSize(QMAX(fn.pointSize()-2, 6));
+        }
+
+        fm = QFontMetrics(fn);
+        r = QRect(fm.boundingRect(0, 0, thumbSize, 0xFFFFFFFF,
+                                  Qt::AlignHCenter | Qt::WordBreak |
+                                  Qt::BreakAnywhere | Qt::AlignTop,
+                                  m_downloadName));
+        m_extraRect.setWidth(r.width());
+        m_extraRect.setHeight(r.height());
+
+        m_textRect.setWidth(QMAX(m_textRect.width(), m_extraRect.width()));
+        m_textRect.setHeight(m_textRect.height() + m_extraRect.height());
+    }
+    
+    int w = QMAX(m_textRect.width(), m_pixRect.width() );
+    int h = m_textRect.height() + m_pixRect.height() ;
+
+    itemRect.setWidth(w+4);
+    itemRect.setHeight(h+4);
+
+    // Center the pix and text rect
+    m_pixRect = QRect(2, 2, m_pixRect.width(), m_pixRect.height());
+    m_textRect = QRect((itemRect.width() - m_textRect.width())/2,
+                       itemRect.height() - m_textRect.height(),
+                       m_textRect.width(), m_textRect.height());
+
+    if (!m_extraRect.isEmpty())
+    {
+        m_extraRect = QRect((itemRect.width() - m_extraRect.width())/2,
+                            itemRect.height() - m_extraRect.height(),
+                            m_extraRect.width(), m_extraRect.height());
+    }
+}
+
+QRect CameraIconViewItem::clickToOpenRect()
+{
+    QRect  r(rect());
+    
+    if (m_pixmap.isNull())
+    {
+        QRect  pixRect(m_pixRect);
+        pixRect.moveBy(r.x(), r.y());
+        return pixRect;
+    }
+
+
+    QRect pixRect(m_pixRect.x() + (m_pixRect.width() - m_pixmap.width())/2,
+                  m_pixRect.y() + (m_pixRect.height() - m_pixmap.height())/2,
+                  m_pixmap.width(),
+                  m_pixmap.height());
+    pixRect.moveBy(r.x(), r.y());
+    return pixRect;
+}
