@@ -47,10 +47,7 @@
 #include <kpopupmenu.h>
 #include <khelpmenu.h>
 
-#include <kdeversion.h>
-#if KDE_IS_VERSION(3,2,0)
 #include <kcalendarsystem.h>
-#endif
 
 extern "C"
 {
@@ -62,7 +59,7 @@ extern "C"
 #include "albummanager.h"
 #include "albumsettings.h"
 #include "album.h"
-#include "dirselectdialog.h"
+#include "albumselectdialog.h"
 #include "renamecustomizer.h"
 #include "animwidget.h"
 #include "gpiteminfodlg.h"
@@ -324,7 +321,10 @@ void CameraUI::slotConnected(bool val)
                                     i18n("Failed to connect to camera. "
                                          "Please make sure its connected "
                                          "properly and turned on. "
-                                         "Would you like to try again?"))
+                                         "Would you like to try again?"), 
+                                    i18n("Connection Failed"),
+                                    i18n("Retry"),
+                                    i18n("Abort"))
           == KMessageBox::Yes)
           QTimer::singleShot(0, m_controller, SLOT(slotConnect()));
       else
@@ -394,22 +394,16 @@ void CameraUI::slotDownloadAll()
 void CameraUI::slotDownload(bool onlySelected)
 {
     AlbumManager* man = AlbumManager::instance();
-    QString libPath(man->getLibraryPath());
-    QString currPath;
 
     Album* album = man->currentAlbum();
-    if (!album || album->type() != Album::PHYSICAL)
-        currPath = libPath;
-    else
-    {
-        currPath = ((PAlbum*)album)->getKURL().path();
-    }
+    if (album && album->type() != Album::PHYSICAL)
+        album = 0;
 
     QString header(i18n("Select Destination Album for "
                         "Importing Camera Images"));
 
     QString newDirName;
-    ThumbItem* firstItem = m_view->firstItem();
+    IconItem* firstItem = m_view->firstItem();
     if (firstItem)
     {
         CameraIconViewItem* iconItem =
@@ -417,24 +411,24 @@ void CameraUI::slotDownload(bool onlySelected)
         
         QDateTime date;
         date.setTime_t(iconItem->itemInfo()->mtime);
-#if KDE_IS_VERSION(3,2,0)
         newDirName = QString("%1, %2, %3")
                      .arg(KGlobal::locale()->calendar()->year(date.date()))
                      .arg(KGlobal::locale()->calendar()->monthName(date.date()))
                      .arg(KGlobal::locale()->calendar()->day(date.date()));
-#else
-        newDirName = QString("%1, %2, %3")
-                     .arg(date.date().year())
-                     .arg(KGlobal::locale()->monthName(date.date().month()))
-                     .arg(date.date().day());
-#endif
     }
-    
-    KURL url = DirSelectDialog::selectDir(libPath, currPath,
-                                          this, header, newDirName,
-                                          m_autoAlbumCheck->isChecked());
-    if (!url.isValid())
+
+
+    album = AlbumSelectDialog::selectAlbum(this,
+                                           (PAlbum*)album,
+                                           header,
+                                           newDirName,
+                                           m_autoAlbumCheck->isChecked());
+
+    if (!album)
         return;
+
+    KURL url;
+    url.setPath(((PAlbum*)album)->folderPath());
     
     m_controller->downloadPrep();
 
@@ -449,7 +443,7 @@ void CameraUI::slotDownload(bool onlySelected)
     autoAlbum  = m_autoAlbumCheck->isChecked();
 
     int total = 0;
-    for (ThumbItem* item = m_view->firstItem(); item;
+    for (IconItem* item = m_view->firstItem(); item;
          item = item->nextItem())
     {
         if (onlySelected && !(item->isSelected()))
@@ -501,7 +495,7 @@ void CameraUI::slotDeleteSelected()
     QStringList files;
     QStringList deleteList;
     
-    for (ThumbItem* item = m_view->firstItem(); item;
+    for (IconItem* item = m_view->firstItem(); item;
          item = item->nextItem())
     {
         CameraIconViewItem* iconItem = static_cast<CameraIconViewItem*>(item);
@@ -546,7 +540,7 @@ void CameraUI::slotDeleteAll()
     QStringList files;
     QStringList deleteList;
     
-    for (ThumbItem* item = m_view->firstItem(); item;
+    for (IconItem* item = m_view->firstItem(); item;
          item = item->nextItem())
     {
         CameraIconViewItem* iconItem = static_cast<CameraIconViewItem*>(item);
