@@ -21,7 +21,9 @@
 #include <qlayout.h>
 #include <qradiobutton.h>
 #include <qcheckbox.h>
+#include <qcombobox.h>
 #include <qlineedit.h>
+#include <qhbox.h>
 #include <qlabel.h>
 #include <qtimer.h>
 
@@ -44,12 +46,36 @@ RenameCustomizer::RenameCustomizer(QWidget* parent)
     layout()->setMargin(10);
 
     QGridLayout* mainLayout = new QGridLayout(layout());
-    
+
     m_renameDefault = new QRadioButton(i18n("Use camera provided names"), this);
     mainLayout->addMultiCellWidget(m_renameDefault, 0, 0, 0, 1);
 
+    m_renameDefaultBox = new QGroupBox( this );
+    m_renameDefaultBox->setFrameStyle(QFrame::NoFrame|QFrame::Plain);
+    m_renameDefaultBox->setColumnLayout(0, Qt::Vertical);
+
+    m_renameDefaultCase = new QLabel( i18n("Change case to"), m_renameDefaultBox );
+    m_renameDefaultCase->setIndent( 10 );
+    m_renameDefaultCase->setSizePolicy( QSizePolicy::Minimum, QSizePolicy::Preferred );
+
+    m_renameDefaultCaseType = new QComboBox( m_renameDefaultBox );
+    m_renameDefaultCaseType->insertItem(i18n("Leave as Is"), 0);
+    m_renameDefaultCaseType->insertItem(i18n("Upper"), 1);
+    m_renameDefaultCaseType->insertItem(i18n("Lower"), 2);
+    m_renameDefaultCaseType->setSizePolicy(QSizePolicy::Minimum, QSizePolicy::Preferred);
+
+    QHBoxLayout* boxLayout =  new QHBoxLayout( m_renameDefaultBox->layout() );
+    boxLayout->setSpacing(5);
+    boxLayout->addWidget( m_renameDefaultCase );
+    boxLayout->addWidget( m_renameDefaultCaseType );
+    boxLayout->addItem(new QSpacerItem(20, 10, QSizePolicy::Expanding,
+                                       QSizePolicy::Minimum ));
+
+    mainLayout->addMultiCellWidget(m_renameDefaultBox, 1, 1, 0, 1);
+
+    
     m_renameCustom = new QRadioButton(i18n("Customize names"), this);
-    mainLayout->addMultiCellWidget(m_renameCustom, 1, 1, 0, 1);
+    mainLayout->addMultiCellWidget(m_renameCustom, 2, 2, 0, 1);
 
     m_renameCustomBox = new QGroupBox(this);
     m_renameCustomBox->setFrameStyle(QFrame::NoFrame|QFrame::Plain);
@@ -60,7 +86,7 @@ RenameCustomizer::RenameCustomizer(QWidget* parent)
 
     QLabel* prefixLabel  = new QLabel(i18n("Prefix:"), m_renameCustomBox);
     renameCustomBoxLayout->addWidget(prefixLabel, 0, 0);
-    
+
     m_renameCustomPrefix = new QLineEdit(m_renameCustomBox);
     renameCustomBoxLayout->addWidget(m_renameCustomPrefix, 0, 1);
 
@@ -71,10 +97,10 @@ RenameCustomizer::RenameCustomizer(QWidget* parent)
     m_renameCustomSeq  = new QCheckBox(i18n("Add sequence number"),
                                        m_renameCustomBox);
     renameCustomBoxLayout->addMultiCellWidget(m_renameCustomSeq, 2, 2, 0, 1);
-    
+
     mainLayout->addItem(new QSpacerItem(20, 10, QSizePolicy::Minimum,
-                                        QSizePolicy::Minimum ), 2, 0);
-    mainLayout->addWidget(m_renameCustomBox, 2, 1);
+                                        QSizePolicy::Minimum ), 3, 0);
+    mainLayout->addWidget(m_renameCustomBox, 3, 1);
 
     // -- setup connections -------------------------------------------------
 
@@ -86,6 +112,8 @@ RenameCustomizer::RenameCustomizer(QWidget* parent)
             SLOT(slotExifChanged(bool)));
     connect(m_renameCustomSeq, SIGNAL(toggled(bool)),
             SLOT(slotSeqChanged(bool)));
+    connect(m_renameDefaultCaseType, SIGNAL(activated(const QString&)),
+            SLOT(slotCaseTypeChanged(const QString&)));
 
     // -- changed timer ----------------------------------------------------
 
@@ -127,6 +155,19 @@ QString RenameCustomizer::nameTemplate() const
     }
 }
 
+RenameCustomizer::Case RenameCustomizer::changeCase() const
+{
+    RenameCustomizer::Case type = NONE;
+
+    if (m_renameDefaultCaseType->currentItem() == 1)
+        type=UPPER;
+    if (m_renameDefaultCaseType->currentItem() == 2)
+        type=LOWER;
+
+    return type;
+}
+
+
 void RenameCustomizer::slotRadioButtonClicked(int)
 {
     QRadioButton* btn = dynamic_cast<QRadioButton*>(selected());
@@ -134,6 +175,7 @@ void RenameCustomizer::slotRadioButtonClicked(int)
         return;
 
     m_renameCustomBox->setEnabled( btn != m_renameDefault );
+    m_renameDefaultBox->setEnabled( btn == m_renameDefault );
     m_changedTimer->start(500, true);
 }
 
@@ -152,6 +194,11 @@ void RenameCustomizer::slotSeqChanged(bool)
     m_changedTimer->start(500, true);
 }
 
+void RenameCustomizer::slotCaseTypeChanged(const QString&)
+{
+    m_changedTimer->start(500, true);
+}
+
 void RenameCustomizer::readSettings()
 {
     KConfig* config = kapp->config();
@@ -159,12 +206,14 @@ void RenameCustomizer::readSettings()
     bool    def;
     bool    exif;
     bool    seq;
+    int     chcaseT;
     QString prefix;
     
     config->setGroup("Camera Settings");
     def     = config->readBoolEntry("Rename Use Default", true);
     exif    = config->readBoolEntry("Rename Add Exif", true);
     seq     = config->readBoolEntry("Rename Add Sequence", true);
+    chcaseT = config->readNumEntry("Case Type", NONE);
     prefix  = config->readEntry("Rename Prefix", i18n("photo"));
 
     if (def)
@@ -172,14 +221,17 @@ void RenameCustomizer::readSettings()
         m_renameDefault->setChecked(true);
         m_renameCustom->setChecked(false);
         m_renameCustomBox->setEnabled(false);
+        m_renameDefaultBox->setEnabled(true);
     }
     else
     {
         m_renameDefault->setChecked(false);
         m_renameCustom->setChecked(true);
         m_renameCustomBox->setEnabled(true);
+        m_renameDefaultBox->setEnabled(false);
     }
 
+    m_renameDefaultCaseType->setCurrentItem(chcaseT);
     m_renameCustomPrefix->setText(prefix);
     m_renameCustomExif->setChecked(exif);
     m_renameCustomSeq->setChecked(seq);
@@ -196,6 +248,8 @@ void RenameCustomizer::saveSettings()
                        m_renameCustomExif->isChecked());
     config->writeEntry("Rename Add Sequence",
                        m_renameCustomSeq->isChecked());
+    config->writeEntry("Case Type",
+                       m_renameDefaultCaseType->currentItem());
     config->writeEntry("Rename Prefix",
                        m_renameCustomPrefix->text());
     config->sync();
