@@ -79,6 +79,7 @@ void UMSCamera::getAllFolders(const QString& folder,
 {
     m_cancel = false;
     subFolderList.clear();
+    subFolderList.append(folder);
     listFolders(folder, subFolderList);
 }
 
@@ -175,7 +176,7 @@ bool UMSCamera::downloadItem(const QString& folder,
     {
         sFile.close();
         kdWarning() << "Failed to open dest file for writing: "
-                    << src << endl;
+                    << dest << endl;
         return false;
     }
 
