@@ -209,7 +209,7 @@ void Canvas::customEvent(QCustomEvent *event)
         getHistogramRect(rc);
         viewport()->update(rc);
     }
-
+    
     delete ed;
 }
 
@@ -350,7 +350,7 @@ void Canvas::load(const QString& filename)
     {
         delete d->imageHistogram;
         d->imageHistogram = 0;
-    }
+    }    
     
     viewport()->setUpdatesEnabled(false);
 
@@ -368,7 +368,7 @@ void Canvas::load(const QString& filename)
     viewport()->setUpdatesEnabled(true);
     viewport()->update();
     if (d->showHistogram)
-	    updateHistogram(true);
+       updateHistogram(true);
    
     emit signalChanged(false, false);
     emit signalZoomChanged(d->zoom);
@@ -459,9 +459,10 @@ void Canvas::updateAutoZoom()
  */
 bool Canvas::updateHistogram(bool invalidate)
 {
-    if (invalidate && d->imageHistogram) {
-	    delete d->imageHistogram;
-	    d->imageHistogram = 0;
+    if (invalidate && d->imageHistogram) 
+    {
+        delete d->imageHistogram;
+        d->imageHistogram = 0;
     }
 
     if (d->imageHistogram == 0) {
@@ -473,7 +474,6 @@ bool Canvas::updateHistogram(bool invalidate)
         // paint busy
         drawHistogramPixmapBusy();
     }
-
     return true;
 }
 
@@ -488,7 +488,7 @@ void Canvas::updateContentsSize()
     d->rbActive      = false;
     viewport()->unsetCursor();
     viewport()->setMouseTracking(false);
-    
+
     if (d->rubber) {
         delete d->rubber;
         d->rubber = 0;
@@ -717,9 +717,9 @@ void Canvas::getHistogramRect(QRect &hrect)
 void Canvas::paintHistogram(const QRect& cr)
 {
     if (!d->showHistogram) 
-	    return;
+       return;
     if (!d->histogramPixmap)
-	    return;
+       return;
 
     QRect rcexposed, rc, rctmp;
 
