@@ -29,12 +29,12 @@
 
 // KDE includes.
 
+#include <kcursor.h>
 #include <klocale.h>
 #include <kconfig.h>
 #include <kstandarddirs.h>
 #include <kapplication.h>
 #include <kmessagebox.h>
-#include <kio/netaccess.h>
 #include <kprinter.h>
 #include <ktempfile.h>
 #include <kimageio.h>
@@ -47,11 +47,14 @@
 #include <kaction.h>
 #include <kstdaccel.h>
 #include <kstdaction.h>
+#include <kstdguiitem.h>
 #include <kstatusbar.h>
 #include <kkeydialog.h>
 #include <kedittoolbar.h>
 #include <kpopupmenu.h>
 
+#include <cstdio>
+
 // LibKexif includes.
 
 #include <libkexif/kexifdata.h>
@@ -74,8 +77,10 @@
 #include "imagewindow.h"
 #include "albumiconview.h"
 #include "albumiconitem.h"
+#include "imageinfo.h"
 #include "imageproperties.h"
 #include "imagedescedit.h"
+#include "tagspopupmenu.h"
 
 
 ImageWindow* ImageWindow::imagewindow()
@@ -129,7 +134,7 @@ ImageWindow::ImageWindow()
         }
     }
 
-    m_contextMenu = dynamic_cast<QPopupMenu*>(factory()->container("RMBMenu", this)); 
+    m_contextMenu = dynamic_cast<QPopupMenu*>(factory()->container("RMBMenu", this));
     
     // -- Some Accels not available from actions -------------
 
@@ -163,6 +168,8 @@ ImageWindow::ImageWindow()
     
     readSettings();
     applySettings();
+    resize(640,480);
+    setAutoSaveSettings("ImageViewer Settings");    
 }
 
 ImageWindow::~ImageWindow()
@@ -472,8 +479,7 @@ void ImageWindow::readSettings()
     bool autoZoom = false;
 
     KConfig* config = kapp->config();
-    applyMainWindowSettings(config, "ImageViewer Settings");
-    config->setGroup("ImageViewer Settings");
+    config->setGroup("ImageViewer Settings");    
 
     // GUI options.
     autoZoom = config->readBoolEntry("AutoZoom", true);
@@ -507,7 +513,6 @@ void ImageWindow::readSettings()
 void ImageWindow::saveSettings()
 {
     KConfig* config = kapp->config();
-    saveMainWindowSettings(config, "ImageViewer Settings");
     
     config->setGroup("ImageViewer Settings");
     config->writeEntry("AutoZoom", m_zoomFitAction->isChecked());
@@ -532,14 +537,11 @@ void ImageWindow::slotLoadCurrent()
     
     if (m_view)
     {
-        ThumbItem* item = m_view->findItem((*it).url());
+        IconItem* item = m_view->findItem((*it).url());
         if (item)
-        {
-            item->setSelected(true);
-            m_view->ensureItemVisible(item);
-        }
+           m_view->setCurrentItem(item);
     }
-    
+
     uint index = m_urlList.findIndex(m_urlCurrent);
 
     if (it != m_urlList.end()) {
@@ -721,7 +723,51 @@ void ImageWindow::slotResize()
 void ImageWindow::slotContextMenu()
 {
     if (m_contextMenu)
+    {
+        TagsPopupMenu* assignTagsMenu = 0;
+        TagsPopupMenu* removeTagsMenu = 0;
+        int separatorID = -1;
+
+        if (m_view)
+        {
+            IconItem* item = m_view->findItem(m_urlCurrent.url());
+            if (item)
+            {
+                Q_LLONG id = ((AlbumIconItem*)item)->imageInfo()->id();
+                QValueList<Q_LLONG> idList;
+                idList.append(id);
+
+                assignTagsMenu = new TagsPopupMenu(idList, 1000,
+                                                   TagsPopupMenu::ASSIGN);
+                removeTagsMenu = new TagsPopupMenu(idList, 2000,
+                                                   TagsPopupMenu::REMOVE);
+
+                separatorID = m_contextMenu->insertSeparator();
+
+                m_contextMenu->insertItem(i18n("Assign Tag"), assignTagsMenu);
+                int i = m_contextMenu->insertItem(i18n("Remove Tag"), removeTagsMenu);
+
+                connect(assignTagsMenu, SIGNAL(signalTagActivated(int)),
+                        SLOT(slotAssignTag(int)));
+                connect(removeTagsMenu, SIGNAL(signalTagActivated(int)),
+                        SLOT(slotRemoveTag(int)));
+
+                AlbumDB* db = AlbumManager::instance()->albumDB();
+                if (!db->hasTags( idList ))
+                    m_contextMenu->setItemEnabled(i,false);
+            }
+        }
+        
         m_contextMenu->exec(QCursor::pos());
+
+        if (separatorID != -1)
+        {
+            m_contextMenu->removeItem(separatorID);
+        }
+        
+        delete assignTagsMenu;
+        delete removeTagsMenu;
+    }
 }
 
 void ImageWindow::slotZoomChanged(float zoom)
@@ -778,14 +824,19 @@ void ImageWindow::slotRotatedOrFlipped()
 
 void ImageWindow::slotFileProperties()
 {
-    if (m_urlCurrent.isValid())
+    if (m_urlCurrent.isValid() && m_view)
     {
+        AlbumIconItem* item = (AlbumIconItem*)m_view->findItem(m_urlCurrent.url());
+        if (!item)
+            return;
+        
         QRect sel = m_canvas->getSelectedArea();
         uint* data   = Digikam::ImlibInterface::instance()->getData();
         int   width  = Digikam::ImlibInterface::instance()->origWidth();
         int   height = Digikam::ImlibInterface::instance()->origHeight();
             
-        ImageProperties properties(this, m_urlCurrent, 
+        ImageProperties properties(ImageProperties::SINGLE, this,
+                                   m_view, item,
                                    sel.isNull() ? 0 : &sel,
                                    data, width, height);
         properties.exec();
@@ -916,14 +967,17 @@ void ImageWindow::slotSave()
 
 bool ImageWindow::save()
 {
-    QString tmpFile = locateLocal("tmp", m_urlCurrent.filename());
+    kapp->setOverrideCursor( KCursor::waitCursor() );
+    KTempFile tmpFile(m_urlCurrent.directory(false), QString::null);
+    tmpFile.setAutoDelete(true);
 
-    bool result = m_canvas->saveAsTmpFile(tmpFile, m_JPEGCompression, 
+    bool result = m_canvas->saveAsTmpFile(tmpFile.name(), m_JPEGCompression, 
                                           m_PNGCompression, m_TIFFCompression);
     
     if (!result)
     {
-        KMessageBox::error(this, i18n("Failed to save file\n\"%1\" to album\n\"%2\".")
+            kapp->restoreOverrideCursor();
+            KMessageBox::error(this, i18n("Failed to save file\n\"%1\" to album\n\"%2\".")
                                 .arg(m_urlCurrent.filename())
                                 .arg(m_urlCurrent.path().section('/', -2, -2)));
         return false;
@@ -935,27 +989,29 @@ bool ImageWindow::save()
     if (exifHolder.hasExif())
     {
         ExifRestorer restorer;
-        restorer.readFile(tmpFile, ExifRestorer::EntireImage);
+        restorer.readFile(tmpFile.name(), ExifRestorer::EntireImage);
         restorer.insertExifData(exifHolder.exifData());
-        restorer.writeFile(tmpFile);
+        restorer.writeFile(tmpFile.name());
     }
     else
-        kdWarning() << ("slotSave::No Exif Data Found") << endl;
+        kdDebug() << "slotSave::No Exif Data Found" << endl;
 
     if( m_rotatedOrFlipped || m_canvas->exifRotated() )
-        KExifUtils::writeOrientation(tmpFile, KExifData::NORMAL);
+        KExifUtils::writeOrientation(tmpFile.name(), KExifData::NORMAL);
 
-    if(!SyncJob::file_move(KURL(tmpFile), m_urlCurrent))
+    if (::rename(QFile::encodeName(tmpFile.name()),
+                 QFile::encodeName(m_urlCurrent.path())) != 0)
     {
-        QString errMsg(SyncJob::lastErrorMsg());
-        KMessageBox::error(this, errMsg, i18n("Error Saving File"));
+        kapp->restoreOverrideCursor();
+        KMessageBox::error(this, i18n("Failed to overwrite original file"),
+                           i18n("Error Saving File"));
         return false;
     }
-
+    
     m_canvas->setModified( false );
     emit signalFileModified(m_urlCurrent);
     QTimer::singleShot(0, this, SLOT(slotLoadCurrent()));
-    
+    kapp->restoreOverrideCursor();
     return true;
 }
 
@@ -970,26 +1026,25 @@ void ImageWindow::slotSaveAs()
               << "image/x-tga" << "image/x-bmp" <<  "image/x-xpm"
               << "image/x-portable-anymap";
 
-    KFileDialog *imageFileSaveDialog = new KFileDialog(m_urlCurrent.directory(),
-                                                       QString::null,
-                                                       this,
-                                                       "imageFileSaveDialog",
-                                                       false);
+    KFileDialog imageFileSaveDialog(m_urlCurrent.directory(),
+                                    QString::null,
+                                    this,
+                                    "imageFileSaveDialog",
+                                    false);
 
-    imageFileSaveDialog->setOperationMode( KFileDialog::Saving );
-    imageFileSaveDialog->setMode( KFile::File );
-    imageFileSaveDialog->setCaption( i18n("New Image File Name") );
-    imageFileSaveDialog->setMimeFilter(mimetypes);
+    imageFileSaveDialog.setOperationMode( KFileDialog::Saving );
+    imageFileSaveDialog.setMode( KFile::File );
+    imageFileSaveDialog.setCaption( i18n("New Image File Name") );
+    imageFileSaveDialog.setMimeFilter(mimetypes);
 
     // Check for cancel.
-    if ( imageFileSaveDialog->exec() != KFileDialog::Accepted )
+    if ( imageFileSaveDialog.exec() != KFileDialog::Accepted )
     {
-       delete imageFileSaveDialog;
        return;
     }
 
-    m_newFile = imageFileSaveDialog->selectedURL();
-    QString format = KImageIO::typeForMime(imageFileSaveDialog->currentMimeFilter());
+    KURL newURL = imageFileSaveDialog.selectedURL();
+    QString format = KImageIO::typeForMime(imageFileSaveDialog.currentMimeFilter());
     if (format.isEmpty())
     {
         // if the format is empty then file format is same as that of the
@@ -997,49 +1052,66 @@ void ImageWindow::slotSaveAs()
         format = QImageIO::imageFormat(m_urlCurrent.path());
     }
     
-    delete imageFileSaveDialog;
-
-    if (!m_newFile.isValid())
+    if (!newURL.isValid())
     {
         KMessageBox::error(this, i18n("Failed to save file\n\"%1\" to Album\n\"%2\".")
-                           .arg(m_newFile.filename())
-                           .arg(m_newFile.path().section('/', -2, -2)));
-        kdWarning() << ("slotSaveAs:: target URL isn't valid !") << endl;
+                           .arg(newURL.filename())
+                           .arg(newURL.path().section('/', -2, -2)));
+        kdWarning() << k_funcinfo << "target URL isn't valid !" << endl;
         return;
     }
 
+    // if new and original url are save use slotSave() ------------------------------
+    
     KURL currURL(m_urlCurrent);
     currURL.cleanPath();
-    m_newFile.cleanPath();
+    newURL.cleanPath();
 
-    if (currURL.equals(m_newFile))
+    if (currURL.equals(newURL))
     {
         slotSave();
         return;
     }
 
-    QFileInfo fi(m_newFile.path());
+    // Check for overwrite ----------------------------------------------------------
+    
+    QFileInfo fi(newURL.path());
+    bool fileExists = false;
     if ( fi.exists() )
     {
         int result =
-            KMessageBox::warningYesNo( this, i18n("About to overwrite file %1. "
-                                                  "Are you sure you want to continue?")
-                                       .arg(m_newFile.filename()) );
+
+            KMessageBox::warningYesNo( this, 
+                                       i18n("A file named \"%1\" already "
+                                            "exists. Are you sure you want "
+                                            "to overwrite it?")
+                                       .arg(newURL.filename()),
+                                       i18n("Overwrite File?"),
+                                       i18n("Overwrite"),
+                                       KStdGuiItem::cancel() );
 
         if (result != KMessageBox::Yes)
             return;
+
+        fileExists = true;
     }
 
-    QString tmpFile = locateLocal("tmp", m_newFile.filename());
+    // Now do the actual saving -----------------------------------------------------
 
-    int result = m_canvas->saveAsTmpFile(tmpFile, m_JPEGCompression, m_PNGCompression,
-                                         m_TIFFCompression, format.lower());
+    kapp->setOverrideCursor( KCursor::waitCursor() );
+    KTempFile tmpFile(newURL.directory(false), QString::null);
+    tmpFile.setAutoDelete(true);
+
+    int result = m_canvas->saveAsTmpFile(tmpFile.name(), m_JPEGCompression,
+                                         m_PNGCompression, m_TIFFCompression,
+                                         format.lower());
 
     if (result == false)
     {
+        kapp->restoreOverrideCursor();
         KMessageBox::error(this, i18n("Failed to save file\n\"%1\" to album\n\"%2\".")
-                           .arg(m_newFile.filename())
-                           .arg(m_newFile.path().section('/', -2, -2)));
+                           .arg(newURL.filename())
+                           .arg(newURL.path().section('/', -2, -2)));
 
         return;
     }
@@ -1054,69 +1126,72 @@ void ImageWindow::slotSaveAs()
         if (exifHolder.hasExif())
         {
             ExifRestorer restorer;
-            restorer.readFile(tmpFile, ExifRestorer::EntireImage);
+            restorer.readFile(tmpFile.name(), ExifRestorer::EntireImage);
             restorer.insertExifData(exifHolder.exifData());
-            restorer.writeFile(tmpFile);
+            restorer.writeFile(tmpFile.name());
         }
         else
-            kdWarning() << ("slotSaveAs::No Exif Data Found") << endl;
+        {
+            kdWarning() << "slotSaveAs::No Exif Data Found" << endl;
+        }
 
         if( m_rotatedOrFlipped )
-            KExifUtils::writeOrientation(tmpFile, KExifData::NORMAL);
+            KExifUtils::writeOrientation(tmpFile.name(), KExifData::NORMAL);
     }
 
-    KIO::FileCopyJob* job = KIO::file_move(KURL(tmpFile), m_newFile,
-                                           -1, true, false, false);
-
-    connect(job, SIGNAL(result(KIO::Job *) ),
-            this, SLOT(slotSaveAsResult(KIO::Job *)));
-}
-
-void ImageWindow::slotSaveAsResult(KIO::Job *job)
-{
-    if (job->error())
+    if (::rename(QFile::encodeName(tmpFile.name()),
+                 QFile::encodeName(newURL.path())) != 0)
     {
-      job->showErrorDialog(this);
-      return;
-    }
-
-    // Added new file URL into list if the new file has been added in the current Album
-
-    KURL su(m_urlCurrent.directory());
-    PAlbum *sourcepAlbum = AlbumManager::instance()->findPAlbum(su);
-
-    if (!sourcepAlbum)
-    {
-        kdWarning() << ("slotSaveAsResult::Cannot found the source album!") << endl;
+        kapp->restoreOverrideCursor();
+        KMessageBox::error(this, i18n("Failed to save to new file"),
+                           i18n("Error Saving File"));
         return;
     }
 
-    KURL tu(m_newFile.directory());
-    PAlbum *targetpAlbum = AlbumManager::instance()->findPAlbum(tu);
+    // Find the src and dest albums ------------------------------------------
 
-    if (!targetpAlbum)
+    KURL srcDirURL(QDir::cleanDirPath(m_urlCurrent.directory()));
+    PAlbum* srcAlbum = AlbumManager::instance()->findPAlbum(srcDirURL);
+    if (!srcAlbum)
     {
-        kdWarning() << ("slotSaveAsResult::Cannot found the target album!") << endl;
+        kapp->restoreOverrideCursor();
+        kdWarning() << k_funcinfo << "Cannot find the source album" << endl;
         return;
     }
 
-    // Copy the metadata from the original image to the target image.
+    KURL dstDirURL(QDir::cleanDirPath(newURL.directory()));
+    PAlbum* dstAlbum = AlbumManager::instance()->findPAlbum(dstDirURL);
+    if (!dstAlbum)
+    {
+        kapp->restoreOverrideCursor();
+        kdWarning() << k_funcinfo << "Cannot find the destination album" << endl;
+        return;
+    }
+        
+    // Now copy the metadata of the original file to the new file ------------
 
     AlbumDB* db = AlbumManager::instance()->albumDB();
-    db->copyItem(sourcepAlbum, m_urlCurrent.fileName(),
-                 targetpAlbum, m_newFile.fileName());
+    db->copyItem(srcAlbum->id(), m_urlCurrent.fileName(),
+                 dstAlbum->id(), newURL.fileName());
 
-    if ( sourcepAlbum == targetpAlbum &&                       // Target Album = current Album ?
-         m_urlList.find(m_newFile) == m_urlList.end() )        // The image file not already exist
-    {                                                          // in the list.
+    // Add new file URL into list if the new file has been added in the current Album
+    
+    if ( srcAlbum == dstAlbum &&                        // Target Album = current Album ?
+         m_urlList.find(newURL) == m_urlList.end() )    // The image file not already exist
+    {                                                   // in the list.
         KURL::List::iterator it = m_urlList.find(m_urlCurrent);
-        m_urlList.insert(it, m_newFile);
-        m_urlCurrent = m_newFile;
+        m_urlList.insert(it, newURL);
+        m_urlCurrent = newURL;
     }
 
-    emit signalFileAdded(m_newFile);
+    if(fileExists)
+        emit signalFileModified(newURL);
+    else
+        emit signalFileAdded(newURL);
 
-    QTimer::singleShot(0, this, SLOT(slotLoadCurrent()));      // Load the new target image.
+    m_canvas->setModified( false );
+    kapp->restoreOverrideCursor();
+    QTimer::singleShot(0, this, SLOT(slotLoadCurrent()));
 }
 
 void ImageWindow::slotToggleFullScreen()
@@ -1136,7 +1211,7 @@ void ImageWindow::slotToggleFullScreen()
         if (obj)
         {
             KToolBar* toolBar = static_cast<KToolBar*>(obj);
-            if (m_fullScreenAction->isPlugged(toolBar))
+            if (m_fullScreenAction->isPlugged(toolBar) && m_removeFullScreenButton)
                 m_fullScreenAction->unplug(toolBar);
             if (toolBar->isHidden())
                 toolBar->show();
@@ -1174,7 +1249,20 @@ void ImageWindow::slotToggleFullScreen()
             if (m_fullScreenHideToolBar)
                 toolBar->hide();
             else
-                m_fullScreenAction->plug(toolBar);
+            {    
+                if ( !m_fullScreenAction->isPlugged(toolBar) )
+                {
+                    m_fullScreenAction->plug(toolBar);
+                    m_removeFullScreenButton=true;
+                }
+                else    
+                {
+                    // If FullScreen button is enable in toolbar settings
+                    // We don't remove it at full screen out.
+                    m_removeFullScreenButton=false;
+                }
+            }
+
         }
 
         // -- Insert all the imageguiclient actions into the accel --
@@ -1298,5 +1386,25 @@ void ImageWindow::slotNewToolbarConfig()
     applyMainWindowSettings(KGlobal::config(), "ImageViewer Settings");
 }
 
+void ImageWindow::slotAssignTag(int tagID)
+{
+    IconItem* item = m_view->findItem(m_urlCurrent.url());
+    if (item)
+    {
+        ((AlbumIconItem*)item)->imageInfo()->setTag(tagID);
+                
+    }
+}
+
+void ImageWindow::slotRemoveTag(int tagID)
+{
+    IconItem* item = m_view->findItem(m_urlCurrent.url());
+    if (item)
+    {
+        ((AlbumIconItem*)item)->imageInfo()->removeTag(tagID);
+                
+    }
+}
+
 #include "imagewindow.moc"
 
