@@ -30,7 +30,6 @@
 // Kde includes.
 
 #include <kurl.h>
-#include <kio/job.h>
 
 class QPopupMenu;
 class QLabel;
@@ -77,7 +76,6 @@ private:
     
     KURL::List             m_urlList;
     KURL                   m_urlCurrent;
-    KURL                   m_newFile;
     
     // Allow to use Image properties and Comments/Tags dialogs from main window.
     AlbumIconView*         m_view;
@@ -90,6 +88,7 @@ private:
     bool                   m_fullScreen;
     bool                   m_fullScreenHideToolBar;
     bool                   m_allowSaving;
+    bool                   m_removeFullScreenButton;
 
     // Actions
 
@@ -174,7 +173,6 @@ private slots:
     
     void slotSave();
     void slotSaveAs();
-    void slotSaveAsResult(KIO::Job *job);
 
     void slotAboutToShowUndoMenu();
     void slotAboutToShowRedoMenu();
@@ -190,6 +188,9 @@ private slots:
     void slotEditKeys();
     void slotConfToolbars();
     void slotNewToolbarConfig();
+
+    void slotAssignTag(int tagID);
+    void slotRemoveTag(int tagID);
     
 protected:
 
