@@ -26,6 +26,9 @@
 extern "C" 
 {
 #include <tiffio.h>
+#include <sys/types.h>
+#include <sys/stat.h>
+#include <unistd.h>
 }
  
 // C++ includes.
@@ -33,6 +36,7 @@ extern "C"
 #include <cmath>
 #include <cstdio>
 #include <cstdlib>
+#include <iostream>
 
 // Qt includes.
 
@@ -98,6 +102,7 @@ public:
     Imlib_Color_Modifier cmod;
     Imlib_Load_Error     errorRet;
     QString              filename;
+    mode_t               filePermissions;
 
     UndoManager*         undoMan;
 };
@@ -188,6 +193,7 @@ bool ImlibInterface::load(const QString& filename)
     d->gamma      = 1.0;
     d->contrast   = 1.0;
     d->brightness = 0.0;
+    d->filePermissions = 0;
 
     imlib_context_set_color_modifier(d->cmod);
     imlib_reset_color_modifier();
@@ -211,14 +217,21 @@ bool ImlibInterface::load(const QString& filename)
             imlib_context_set_image(d->image);
             DATA32* data = imlib_image_get_data_for_reading_only();
             memcpy(data, qtimage.bits(), qtimage.numBytes());
-            kdDebug() << "Loaded image with kde imageio resources: "
-                      << filename
+            std::cout << "Loaded image with kde imageio resources: "
+                      << filename.ascii()
                       << ", width="  << qtimage.width()
-                      << ", height=" << qtimage.height() << endl;
+                      << ", height=" << qtimage.height() << std::endl;
         }
     }
 
-    if (d->image) {
+    if (d->image)
+    {
+        struct stat stbuf;
+        if (::stat(QFile::encodeName(filename), &stbuf) == 0)
+        {
+            d->filePermissions = stbuf.st_mode;
+        }
+        
         imlib_context_set_image(d->image);
         imlib_image_set_changes_on_disk();
 
@@ -1006,6 +1019,12 @@ bool ImlibInterface::saveAction(const QString& saveFile, int JPEGcompression,
         return false;  // Do not reload the file if saving failed !
     }
 
+    // file saved. now preserve the permissions
+    if (d->filePermissions != 0)
+    {
+        ::chmod(QFile::encodeName(saveFile), d->filePermissions);
+    }
+
     return true;
 }
 
